@@ -1,9 +1,11 @@
 (load (merge-pathnames "../clcs/gcl_clcs_macros.lisp" system:*system-directory*))
+;(load (merge-pathnames "../clcs/gcl_clcs_restart.lisp" system:*system-directory*))
 
 (in-package "CONDITIONS")
 
 (defvar *shadowed-symbols1* 
-  '(ASSERT ETYPECASE CTYPECASE ECASE CCASE))
+;  '(ASSERT ETYPECASE CTYPECASE ECASE CCASE))
+  '())
 
 (defun install-symbol (real clcs)
   (unless (get real 'definition-before-clcs)
@@ -38,3 +40,4 @@
   nil)
 
 (install-clcs-symbols)
+;(load (merge-pathnames "../clcs/sys-proclaim.lisp" system:*system-directory*))
