@@ -19,11 +19,11 @@
 (PROCLAIM
     '(FTYPE (FUNCTION (T (ARRAY T (*)) FIXNUM T) FIXNUM) PUSH-ARRAY)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) IS-EQ-TEST-ITEM-LIST C2COMPILER-LET
+    '(FTYPE (FUNCTION (T T T) *)  C2COMPILER-LET
             C2IF C2LABELS C2FLET WT-INLINE)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T *) T) DO-VECTOR-MAP DO-SEQUENCE-SEARCH
-            DO-LIST-SEARCH SUPER-RANGE C2LAMBDA-EXPR INLINE-ARGS
+    '(FTYPE (FUNCTION (T T *) T) RANDOM-PROPAGATOR LIST-TP-TEST DO-VECTOR-MAP DO-SEQUENCE-SEARCH
+            DO-LIST-SEARCH C2LAMBDA-EXPR INLINE-ARGS
             AREF-PROPAGATOR C2FUNCALL ARRAY-ROW-MAJOR-INDEX-EXPANDER
             FLOOR-PROPAGATOR)) 
 (PROCLAIM
@@ -33,7 +33,7 @@
     '(FTYPE (FUNCTION (T (ARRAY T (*)) SEQIND SEQIND T) FIXNUM)
             BSEARCHLEQ)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) ASSIGN-DOWN-VARS TOO-FEW-ARGS
+    '(FTYPE (FUNCTION (T T T) T)  cons-propagator do-setq-tp cons-tp-limit ASSIGN-DOWN-VARS TOO-FEW-ARGS
             TOO-MANY-ARGS ASH-PROPAGATOR T3DEFCFUN
             NOTE-BRANCH-ELIMINATION BOOLE3 C2PROGV SET-VAR
             CMP-EXPAND-MACRO AND-FORM-TYPE C2GO C2TAGBODY
@@ -52,7 +52,7 @@
     '(FTYPE (FUNCTION (T T T *) T) POSSIBLE-EQ-LIST-SEARCH NUM-TYPE-REL
             WT-SIMPLE-CALL)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T) T3DEFUN-NORMAL T3DEFUN-VARARG
+    '(FTYPE (FUNCTION (T T T T) T) IS-EQ-TEST-ITEM-LIST T3DEFUN-NORMAL T3DEFUN-VARARG
             C1MAKE-VAR C2SWITCH INLINE-TYPE-MATCHES C2STRUCTURE-REF
             C2CALL-UNKNOWN-GLOBAL C2CALL-GLOBAL MY-CALL PUT-PROCLS
             WT-GLOBAL-ENTRY)) 
@@ -82,13 +82,13 @@
             WT-TO-STRING)) 
 (PROCLAIM
     '(FTYPE (FUNCTION (*) T) CS-PUSH FCALLN-INLINE MAKE-VAR
-            RANDOM-PROPAGATOR MAKE-TAG LIST*-INLINE MAKE-INFO
+             MAKE-TAG LIST*-INLINE MAKE-INFO
             LIST-INLINE CMP-ARRAY-DIMENSION-INLINE-TYPES
             CMP-ASET-INLINE-TYPES CMP-AREF-INLINE-TYPES
             CMP-ARRAY-ELEMENT-TYPE MAKE-FUN MAKE-BLK WT-CLINK
             WT-C-PUSH)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T) T) CMP-NORM-TP SCH-GLOBAL COERCE-TO-INTEGER-TYPE T3CLINES
+    '(FTYPE (FUNCTION (T) T) CMP-RESOLVE-TP CMP-NORM-TP SCH-GLOBAL COERCE-TO-INTEGER-TYPE T3CLINES
             VOLATILE IS-LOCAL-VAR-TYPE IS-LOCAL-ARG-TYPE
             IS-GLOBAL-ARG-TYPE LONG-FLOAT-LOC-P COERCE-TO-ONE-VALUE
             COPY-INFO CONSTANT-FOLD-P CONS-TO-LISTA SCH-LOCAL-FUN
@@ -97,7 +97,7 @@
             C2VAR-KIND VAR-P VAR-TYPE VAR-LOC VAR-REF-CCB VAR-REF
             VAR-KIND VAR-NAME C1PSETQ C1PROGV C1SETQ C1ADD-GLOBALS
             C1VREF C1VAR UNDEFINED-VARIABLE CMP-MACROEXPAND-1
-            CMP-MACROEXPAND PROMOTED-C-TYPE OBJECT-TYPE INTEGER-TYPEP
+            CMP-MACROEXPAND PROMOTED-C-TYPE INTEGER-TYPEP
             RESET-INFO-TYPE TYPE-FILTER LITERALP DEFAULT-INIT T2DECLARE
             T2ORDINARY C2GO-CCB C2GO-CLB C2GO-LOCAL C2TAGBODY-CCB
             C2TAGBODY-CLB C2TAGBODY-BODY C2TAGBODY-LOCAL C2FUNCTION
@@ -154,14 +154,14 @@
             BLK-REF-CCB BLK-REF-CLB BLK-REF BLK-NAME)) 
 (PROCLAIM
     '(FTYPE (FUNCTION (T T) *) C2DECL-BODY C2RETURN-LOCAL C2BLOCK-LOCAL
-            C2BLOCK LIST-TP-TEST C1SYMBOL-FUN C1BODY WT-INLINE-LOC)) 
+            C2BLOCK C1SYMBOL-FUN C1BODY WT-INLINE-LOC)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T *) T) CMPNOTE CMPWARN CMPERR INTEGER-NORM-FORM
+    '(FTYPE (FUNCTION (T *) T) OBJECT-TYPE SUPER-RANGE CMPNOTE CMPWARN CMPERR INTEGER-NORM-FORM
             INIT-NAME UNWIND-EXIT C1LAMBDA-EXPR C1CASE
             FAST-LINK-PROCLAIMED-TYPE-P WT-COMMENT ADD-INIT WT-CVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T) T) C-FUNCTION-NAME)) 
+(PROCLAIM '(FTYPE (FUNCTION (T T T) T) C-FUNCTION-NAME)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) COMPILER-CLEAR-COMPILER-PROPERTIES
+    '(FTYPE (FUNCTION (T T) T) cdr-ropagator set-var-init-type CMP-NTHCDR COMPILER-CLEAR-COMPILER-PROPERTIES
             COMPILER-DEF-HOOK CONS-INLINE IS-REP-REFERRED COERCE-LOC
             CONVERT-CASE-TO-SWITCH CO1SUBLIS CO1SPECIAL-FIX-DECL
             CO1CONSTANT-FOLD CO1VECTOR-PUSH CO1WRITE-CHAR CO1WRITE-BYTE
