@@ -461,42 +461,6 @@ struct string {           /*  string header  */
                            /*  string length  */
 };
 
-#define stack_string(a_,b_) struct string _s={0};\
-                            object a_=(object)&_s;\
-                            set_type_of((a_),t_string);\
-                            (a_)->st.st_self=(void *)(b_);\
-                            (a_)->st.st_dim=(a_)->st.st_fillp=strlen(b_)
-
-#define stack_fixnum(a_,b_) struct fixnum_struct _s={0};\
-                            object a_;\
-                            if (is_imm_fix(b_)) (a_)=make_fixnum(b_); else {\
-                            (a_)=(object)&_s;\
-                            set_type_of((a_),t_fixnum);\
-                            (a_)->FIX.FIXVAL=(b_);}
-
-/*FIXME the stack stuff is dangerous It works for error handling, but
-  simple errors may evan pass the format tring up the stack as a slot
-  in ansi*/
-/* #define TYPE_ERROR(a_,b_) {stack_string(tp_err,"~S is not of type ~S.");\ */
-/*                            Icall_error_handler(sKwrong_type_argument,tp_err,2,(a_),(b_));} */
-
-#define TYPE_ERROR(a_,b_) ({object tp_err=make_simple_string("~S is not of type ~S.");\
-                           Icall_error_handler(sKwrong_type_argument,tp_err,2,(a_),(b_));})
-
-#define CONTROL_ERROR(a_) ({object tp_err=make_simple_string(a_);\
-                           Icall_error_handler(sKcontrol_error,tp_err,0);})
-
-#define READER_ERROR(a_,b_)  ({object rd_err=make_simple_string("Read error on stream ~S: " b_);\
-                              Icall_error_handler(sKreader_error,rd_err,1,(a_));})
-
-#define NERROR(a_)  ({object fmt=make_simple_string(a_ ": line ~a, file ~a, function ~a");\
-                    {object line=make_fixnum(__LINE__);\
-                    {object file=make_simple_string(__FILE__);\
-                    {object function=make_simple_string(__FUNCTION__);\
-                     Icall_error_handler(sKerror,fmt,3,line,file,function);}}}})
-
-#define ASSERT(a_) if (!(a_)) NERROR("The assertion " #a_ " failed")
-
 struct ustring {
 
   FIRSTWORD;
@@ -519,10 +483,10 @@ struct ustring {
 #define  INT_GCL(x,i)  ((( int *)(x)->ust.ust_self)[i])
 
 #define BV_OFFSET(x) ((type_of(x)==t_bitvector ? x->bv.bv_offset : \
-                       type_of(x)== t_array ? x->a.a_offset : (abort(),0)))
+                       type_of(x)== t_array ? x->a.a_offset : (gcl_abort(),0)))
 
 #define SET_BV_OFFSET(x,val) ((type_of(x)==t_bitvector ? x->bv.bv_offset = val : \
-                               type_of(x)== t_array ? x->a.a_offset=val : (abort(),0)))
+                               type_of(x)== t_array ? x->a.a_offset=val : (gcl_abort(),0)))
 
 struct bitvector {         /*  bitvector header  */
 
@@ -685,9 +649,7 @@ struct stream {
 };
 /* flags */
 #define GET_STREAM_FLAG(strm,name) ((strm)->sm.sm_flags & (1<<(name)))
-#define SET_STREAM_FLAG(strm,name,val) (val ? \
-                      ((strm)->sm.sm_flags |= (1<<(name))) : \
-   ((strm)->sm.sm_flags &= ~(1<<(name)))) 
+#define SET_STREAM_FLAG(strm,name,val) {if (val) (strm)->sm.sm_flags |= (1<<(name)); else (strm)->sm.sm_flags &= ~(1<<(name));}
 
 #define GCL_MODE_BLOCKING 1
 #define GCL_MODE_NON_BLOCKING 0
@@ -835,7 +797,7 @@ struct sfun {
   object (*sfn_self)();    /* C start address of code */
   object   sfn_data;       /* To object holding VV vector */
   fixnum   sfn_argd;       /* description of args + number */
-  SPAD;
+  fixnum   sfn_nval;
 
 };
 
@@ -847,6 +809,16 @@ struct ifun {
 
 };
 
+#define CMVFUNP(x_) ({enum type _t=type_of(x_);((_t==t_sfun || _t==t_vfun || _t==t_gfun) && x_->sfn.sfn_argd&MVRET_BIT);})
+
+#if SIZEOF_LONG == 4
+#define VFILL_BITS 8
+#elif SIZEOF_LONG == 8
+#define VFILL_BITS 40
+#else
+#error Cannot calculate VFILL_BITS
+#endif
+
 struct vfun {
 
   FIRSTWORD; 
@@ -854,9 +826,18 @@ struct vfun {
   object           vfn_name;       /* name */
   object         (*vfn_self)();    /* C start address of code */
   object           vfn_data;       /* To object holding VV data */
-  uhfixnum         vfn_minargs;    /* Min args and where varargs start */
-  uhfixnum         vfn_maxargs;    /* Max number of args */
-  SPAD;
+#ifndef WORDS_BIGENDIAN
+  fixnum           vfn_minargs:8;  /* Min args and where varargs start */
+  fixnum           vfn_mv     :8;  /* mv bits */
+  fixnum           vfn_maxargs:8;  /* Max number of args */
+  fixnum           vfn_unused :VFILL_BITS; 
+#else
+  fixnum           vfn_unused :VFILL_BITS; 
+  fixnum           vfn_maxargs:8;  /* Max number of args */
+  fixnum           vfn_mv     :8;  /* mv bits */
+  fixnum           vfn_minargs:8;  /* Min args and where varargs start */
+#endif
+  fixnum           vfn_nval;
 
 };
 struct cfdata {
@@ -963,6 +944,13 @@ struct freelist {
 #define set_type_of(x,y) ({object _x=(object)(x);enum type _y=(y);*(fixnum *)(_x)&=TYPE_BITS;\
                            if (_y!=t_cons) {_x->d.e=1;_x->d.t=_y;}})
 
+/*
+
+C predicates
+
+*/
+
+
 #define consp(x)         ({register object _z=(object)(x);\
                            (_z!=Cnil && !is_imm_fixnum(_z) && valid_cdr(_z));})
 #define listp(x)         ({register object _z=(object)(x);\
@@ -970,6 +958,42 @@ struct freelist {
 #define atom(x)          ({register object _z=(object)(x);\
                            (_z==Cnil || is_imm_fixnum(_z) || !valid_cdr(_z));})
 
+#define join(a_,b_) a_ ## b_
+#define Join(a_,b_) join(a_,b_)
+
+
+#define SPP(a_,b_) (type_of(a_)==Join(t_,b_))
+#define streamp(a_)    SPP(a_,stream)
+#define packagep(a_)   SPP(a_,package)
+#define hashtablep(a_) SPP(a_,hashtable)
+#define randomp(a_)    SPP(a_,random)
+#define characterp(a_) SPP(a_,character)
+#define symbolp(a_)    SPP(a_,symbol)
+#define stringp(a_)    SPP(a_,string)
+#define fixnump(a_)    SPP(a_,fixnum)
+#define readtablep(a_) SPP(a_,readtable)
+
+extern int big_sign(object);
+#define integerp(a_) ({enum type _tp=type_of(a_); _tp >= t_fixnum     && _tp <= t_bignum;})
+#define non_negative_integerp(a_) ({enum type _tp=type_of(a_); (_tp == t_fixnum && fix(a_)>=0) || (_tp==t_bignum && big_sign(a_)>=0);})
+#define rationalp(a_)({enum type _tp=type_of(a_); _tp >= t_fixnum     && _tp <= t_ratio;})
+#define floatp(a_)   ({enum type _tp=type_of(a_); _tp == t_shortfloat || _tp == t_longfloat;})
+#define realp(a_)    ({enum type _tp=type_of(a_); _tp >= t_fixnum     && _tp < t_complex;})
+#define numberp(a_)  ({enum type _tp=type_of(a_); _tp >= t_fixnum     && _tp <= t_complex;})
+#define arrayp(a_)   ({enum type _tp=type_of(a_); _tp >= t_string     && _tp <= t_array;})
+#define vectorp(a_)  ({enum type _tp=type_of(a_); _tp >= t_string     && _tp < t_array;})
+
+#define string_symbolp(a_)                 ({enum type _tp=type_of(a_); _tp == t_string || _tp == t_symbol;})
+#define pathname_string_symbolp(a_)        ({enum type _tp=type_of(a_); _tp==t_pathname || _tp == t_string\
+                                                                     || _tp == t_symbol;})
+#define pathname_string_symbol_streamp(a_) ({enum type _tp=type_of(a_); _tp==t_pathname || _tp == t_string\
+                                                                     || _tp == t_symbol || _tp==t_stream;})
+#define eql_is_eq(a_)    (is_imm_fixnum(a_) || ({enum type _tp=type_of(a_); _tp == t_cons || _tp > t_character;}))
+#define equal_is_eq(a_)  (is_imm_fixnum(a_) || type_of(a_)>t_bitvector)
+#define equalp_is_eq(a_) (type_of(a_)>t_structure)
+
+
+
 /*
  Storage manager for each type.
 */
@@ -1100,9 +1124,9 @@ EXTER char *tmp_alloc;
 #define HIND 0
 #define LIND 1
 #endif
-#ifndef VOL
-#define VOL
-#endif
+/* #ifndef VOL */
+#define VOL volatile
+/* #endif */
 
 
 #define isUpper(xxx) (((xxx)&0200) == 0 && isupper((int)xxx))
@@ -1111,21 +1135,6 @@ EXTER char *tmp_alloc;
 enum ftype {f_object,f_fixnum,f_integer};
 EXTER char *alloca_val;
 
-/*          ...xx|xx|xxxx|xxxx|   
-       ret  Narg     */
-
-/*    a9a8a7a6a5a4a3a4a3a2a1a0rrrrnnnnnnnn
-         ai=argtype(i)         ret   nargs
- */
-#define SFUN_NARGS(x)   (x & 0xff) /* 8 bits */
-#define RESTYPE(x)      (x<<8)   /* 3 bits */
-/* set if the VFUN_NARGS = m ; has been set correctly */
-#define VFUN_NARG_BIT   (1 <<11) 
-#define ARGTYPE(i,x)    ((x) <<(12+(i*2)))
-#define ARGTYPE1(x)     (1 | ARGTYPE(0,x))
-#define ARGTYPE2(x,y)   (2 | ARGTYPE(0,x)  | ARGTYPE(1,y))
-#define ARGTYPE3(x,y,z) (3 | ARGTYPE(0,x) | ARGTYPE(1,y) | ARGTYPE(2,z))
-
 object make_si_sfun();
 EXTER object MVloc[10];
 
@@ -1194,19 +1203,21 @@ EXTER object MVloc[10];
 /* Number of args supplied to a variable arg t_vfun
  Used by the C function to set optionals */
 
+#define MULTIPLE_VALUES_LIMIT 32
 struct call_data { 
 
 object  fun;
 hfixnum argd;
 hfixnum nvalues;
-object  values[50];
+object  values[MULTIPLE_VALUES_LIMIT];
 double  double_return;
 
 };
 EXTER struct call_data fcall;
 
 #define  VFUN_NARGS fcall.argd
-#define RETURN2(x,y) do{fcall.values[2]=y;fcall.nvalues=2;return (x) ;} while(0)
+#define RETURN3(x,y,z) do{fcall.values[2]=z;fcall.values[1]=y;fcall.nvalues=3;return (x) ;} while(0)
+#define RETURN2(x,y) do{fcall.values[1]=y;fcall.nvalues=2;return (x) ;} while(0)
 #define RETURN1(x) do{fcall.nvalues=1; return (x) ;} while(0)
 #define RETURN0  do{fcall.nvalues=0; return Cnil ;} while(0)
 
@@ -1237,7 +1248,7 @@ EXTER object sSlambda_block_expanded;
 # ifdef __GNUC__ 
 # define assert(ex)\
 {if (!(ex)){(void)fprintf(stderr, \
-    "Assertion failed: file \"%s\", line %d\n", __FILE__, __LINE__);exit(1);}}
+    "Assertion failed: file \"%s\", line %d\n", __FILE__, __LINE__);gcl_abort();}}
 # else
 # define assert(ex)
 # endif
@@ -1245,8 +1256,10 @@ EXTER object sSlambda_block_expanded;
 #ifndef FIX_PATH_STRING
 #define FIX_PATH_STRING(file) file
 #endif
- 
-#define CHECK_INTERRUPT   if (signals_pending) raise_pending_signals(sig_safe)
+
+#ifndef CHECK_INTERRUPT
+#  define CHECK_INTERRUPT   if (signals_pending) raise_pending_signals(sig_safe)
+#endif
 
 #define BEGIN_NO_INTERRUPT \
  plong old_signals_allowed = signals_allowed; \
@@ -1261,7 +1274,7 @@ EXTER object sSlambda_block_expanded;
 #define END_NO_INTERRUPT_SAFE \
   signals_allowed = old_signals_allowed; \
   if (signals_pending) \
-    do{ if(signals_allowed ==0) /* should not get here*/abort(); \
+    do{ if(signals_allowed ==0) /* should not get here*/gcl_abort(); \
    raise_pending_signals(sig_safe)}while(0)
 
 void raise_pending_signals();
@@ -1370,8 +1383,38 @@ extern void *stack_alloc_start,*stack_alloc_end;
                                             _x->sm.sm_fd=fd_;\
                                             _x;})
 
-#define writable_ptr(a_) (((void *)(a_)>=DBEGIN && (void *)(a_)<(void *)heap_end) || is_imm_fixnum(a_))
+#define writable_ptr(a_) (((unsigned long)(a_)>=DBEGIN && (void *)(a_)<(void *)heap_end) || is_imm_fixnum(a_))
 
 #define write_pointer_object(a_,b_) fSwrite_pointer_object(a_,b_)
 
 #define read_pointer_object(a_) fSread_pointer_object(a_)
+
+#define fixnum_float_contagion(a_,b_) \
+  ({register object _a=(a_),_x=_a,_b=(b_);\
+    register enum type _ta=type_of(_a),_tb=type_of(_b);\
+    if (_ta!=_tb)\
+       switch(_ta) {\
+          case t_shortfloat: if (_tb==t_longfloat) _x=make_longfloat(sf(_a)); break;\
+          case t_fixnum: \
+              switch(_tb) {\
+                  case t_longfloat:  _x=make_longfloat (fix(_a));break;\
+                  case t_shortfloat: _x=make_shortfloat(fix(_a));break;\
+                  default: break;}\
+          break;\
+          default: break;}\
+   _x;})
+                                        
+
+#define make_cons(a_,b_) ({register struct typemanager *_tm=tm_table+(int)t_cons;register object _x;if (!stack_alloc_start && _tm->tm_free) {_x=_tm->tm_free;_tm->tm_free=OBJ_LINK(_x);_tm->tm_nfree--;_tm->tm_nused++;_x->c.c_car=(a_);_x->c.c_cdr=(b_);} else _x=make_cons1(a_,b_);_x;})
+
+EXTER object null_string;
+#define FEerror(a_,b_...)   Icall_error_handler(sLerror,null_string,\
+                            4,sKformat_control,make_simple_string(a_),sKformat_arguments,list(b_))
+#define TYPE_ERROR(a_,b_)   Icall_error_handler(sLtype_error,null_string,\
+                            4,sKdatum,(a_),sKexpected_type,(b_))
+#define FEinvalid_form(a_,b_) \
+  Icall_error_handler(sLprogram_error,null_string,4,\
+                      sKformat_control,make_simple_string(a_),\
+                      sKformat_arguments,list(1,(b_)))
+#define FEinvalid_variable(a_,b_) FEinvalid_form(a_,b_)
+#define FEwrong_type_argument(a_,b_) TYPE_ERROR(b_,a_)
