@@ -2,7 +2,7 @@
 /* alloc.c:149:OF */ extern void add_page_to_freelist (char *p, struct typemanager *tm); /* (p, tm) char *p; struct typemanager *tm; */
 /* alloc.c:196:OF */ extern object type_name (int t); /* (t) int t; */
 /* alloc.c:213:OF */ extern object alloc_object (enum type t); /* (t) enum type t; */
-/* alloc.c:296:OF */ extern object make_cons (object a, object d); /* (a, d) object a; object d; */
+/* alloc.c:296:OF */ extern object make_cons1 (object a, object d); /* (a, d) object a; object d; */
 /* alloc.c:364:OF */ extern object on_stack_cons (object x, object y); /* (x, y) object x; object y; */
 /* alloc.c:376:OF */ extern object fSallocated (object typ); /* (typ) object typ; */
 /* alloc.c:401:OF */ extern object fSreset_number_used (object typ); /* (typ) object typ; */
@@ -32,7 +32,7 @@
 /* array.c::OF */ extern object fSmake_vector1_1 (fixnum n,fixnum elt_type,object staticp); 
 /* array.c:738:OF */ extern void adjust_displaced (object x, long diff); /* (x, diff) object x; int diff; */
 /* array.c:790:OF */ extern void gset (void *p1, void *val, int n, int typ); /* (p1, val, n, typ) char *p1; char *val; int n; int typ; */
-/* array.c:831:OF */ extern object fScopy_array_portion (object x, object y,fixnum i1,fixnum i2, object n1); /* (x, y, i1, i2, n1) object x; object y; int i1; int i2; int n1; */
+/* array.c:831:OF */ extern object fScopy_array_portion (object x, object y,object o1,object o2, object n1); /* (x, y, i1, i2, n1) object x; object y; int i1; int i2; int n1; */
 /* array.c:879:OF */ extern void array_allocself (object x, int staticp, object dflt); /* (x, staticp, dflt) object x; int staticp; object dflt; */
 /* array.c:920:OF */ extern void siLfill_pointer_set (void); /* () */
 /* array.c:923:OF */ extern object fSfill_pointer_set (object x,fixnum i); /* (x, i) object x; int i; */
@@ -82,6 +82,7 @@
 /* gmp_big.c:454:OF */ extern object maybe_replace_big (object x); /* (x) object x; */
 /* gmp_big.c:472:OF */ extern object bignum2 ( int h,  int l); /* (h, l) unsigned int h; unsigned int l; */
 /* gmp_big.c:482:OF */ extern void integer_quotient_remainder_1 (object x, object y, object *qp, object *rp); /* (x, y, qp, rp) object x; object y; object *qp; object *rp; */
+/* gmp_big.c:482:OF */ extern void integer_quotient_remainder_1_ui (object x, unsigned long y, object *qp, object *rp); /* (x, y, qp, rp) object x; object y; object *qp; object *rp; */
 /* gmp_big.c:502:OF */ extern object coerce_big_to_string (object x, int printbase); /* (x, printbase) object x; int printbase; */
 /* gmp_big.c:521:OF */ extern void gcl_init_big (void); /* () */
 /* big.c:72:OF */ extern int big_sign (object x); /* (x) object x; */
@@ -111,16 +112,17 @@ struct key {short n,allow_other_keys;
 /* catch.c:61:OF */ extern object fSerror_set (object x0); /* (x0) object x0; */
 /* catch.c:166:OF */ extern void gcl_init_catch (void); /* () */
 /* cfun.c:37:OF */ extern object make_cfun (void (*self)(), object name, object data, char *start, int size); /* (self, name, data, start, size) int (*self)(); object name; object data; char *start; int size; */
-/* cfun.c:56:OF */ extern object make_sfun (object name, object (*self)(), int argd, object data); /* (name, self, argd, data) object name; int (*self)(); int argd; object data; */
+/* cfun.c:56:OF */ extern object make_sfun (object name, object (*self)(), int argd, object data,fixnum nval); /* (name, self, argd, data) object name; int (*self)(); int argd; object data; */
 /* cfun.c:91:OF */ extern object make_cclosure_new (void (*self)(), object name, object env, object data); /* (self, name, env, data) int (*self)(); object name; object env; object data; */
 /* cfun.c:108:OF */ extern object make_cclosure (void (*self)(), object name, object env, object data, char *start, int size); /* (self, name, env, data, start, size) int (*self)(); object name; object env; object data; char *start; int size; */
 /* cfun.c:124:OF */ extern object fSmc (object name, object address); /* (name, address) object name; object address; */
-/* cfun.c:150:OF */ extern object fSmfsfun (object name, object address, object argd); /* (name, address, argd) object name; object address; object argd; */
-/* cfun.c:174:OF */ extern object fSmfvfun (object name, object address, object argd); /* (name, address, argd) object name; object address; object argd; */
-/* cfun.c:193:OF */ extern object fSmfvfun_key (object symbol, object address, object argd, object keys); /* (symbol, address, argd, keys) object symbol; object address; object argd; object keys; */
+/* cfun.c:150:OF */ extern object fSmfsfun (object name, object address, object argd,object nval); /* (name, address, argd) object name; object address; object argd; */
+/* cfun.c:174:OF */ extern object fSmfvfun (object name, object address, object argd,object nval); /* (name, address, argd) object name; object address; object argd; */
+/* cfun.c:193:OF */ extern object fSmfvfun_key (object symbol, object address, object argd, object keys,object nval); /* (symbol, address, argd, keys) object symbol; object address; object argd; object keys; */
 /* cfun.c:221:OF */ extern object fSmf (object name, object addr); /* (name, addr) object name; object addr; */
 /* cfun.c:269:OF */ extern object fSmm (object name, object addr); /* (name, addr) object name; object addr; */
 /* cfun.c:283:OF */ extern object make_function_internal (char *s, void(*f)()); /* (s, f) char *s; int (*f)(); */
+/* cfun.c:283:OF */ extern object make_macro_internal (char *s, void(*f)()); /* (s, f) char *s; int (*f)(); */
 /* cfun.c:299:OF */ extern object make_si_sfun_internal (char *s, object (*f)(), int argd); /* (s, f, argd) char *s; int (*f)(); int argd; */
 /* cfun.c:322:OF */ extern object make_si_function_internal (char *s, void (*f) ()); /* (s, f) char *s; int (*f)(); */
 /* cfun.c:341:OF */ extern object make_special_form_internal (char *s, void (*f)()); /* (s, f) char *s; int (*f)(); */
@@ -141,6 +143,7 @@ struct key {short n,allow_other_keys;
 /* cmpaux.c:106:OF */ /* extern int ifloor (int x, int y); */ /* (x, y) int x; int y; */
 /* cmpaux.c:124:OF */ /* extern int imod (int x, int y); */ /* (x, y) int x; int y; */
 /* cmpaux.c:185:OF */ extern int object_to_int (object x); /* (x) object x; */
+/* cmpaux.c:185:OF */ extern fixnum object_to_fixnum (object x); /* (x) object x; */
 /* cmpaux.c:263:OF */ extern char *object_to_string (object x); /* (x) object x; */
 typedef int (*FUNC)();
 /* cmpaux.c:294:OF */ extern void call_init (int init_address, object memory, object fasl_vec, FUNC fptr); /* (init_address, memory, fasl_vec, fptr) int init_address; object memory; object fasl_vec; FUNC fptr; */
@@ -150,19 +153,19 @@ typedef int (*FUNC)();
 /* error.c:38:OF */ extern void terminal_interrupt (int correctable); /* (correctable) int correctable; */
 /* error.c:147:OF */ extern void Lerror (void); /* () */
 /* error.c:164:OF */ extern void Lcerror (void); /* () */
-/* error.c:184:OF */ extern void FEerror (char *s, int num, ... ); /* (s, num, arg1, arg2, arg3, arg4) char *s; int num; object arg1; object arg2; object arg3; object arg4; */
-/* error.c:203:OF */ extern void FEwrong_type_argument (object type, object value); /* (type, value) object type; object value; */
-/* error.c:210:OF */ extern void FEtoo_few_arguments (object *base, object *top); /* (base, top) object *base; object *top; */
-/* error.c:219:OF */ extern void FEtoo_few_argumentsF (object args); /* (args) object args; */
-/* error.c:227:OF */ extern void FEtoo_many_arguments (object *base, object *top); /* (base, top) object *base; object *top; */
-/* error.c:234:OF */ extern void FEtoo_many_argumentsF (object args); /* (args) object args; */
-/* error.c:247:OF */ extern void FEunexpected_keyword (object key); /* (key) object key; */
-/* error.c:258:OF */ extern void FEinvalid_form (char *s, object form); /* (s, form) char *s; object form; */
-/* error.c:266:OF */ extern void FEunbound_variable (object sym); /* (sym) object sym; */
-/* error.c:273:OF */ extern void FEinvalid_variable (char *s, object obj); /* (s, obj) char *s; object obj; */
-/* error.c:280:OF */ extern void FEundefined_function (object fname); /* (fname) object fname; */
-/* error.c:287:OF */ extern void FEinvalid_function (object obj); /* (obj) object obj; */
-/* error.c:297:OF */ extern object CEerror (char *error_str, char *cont_str, int num, object arg1, object arg2, object arg3, object arg4); /* (error_str, cont_str, num, arg1, arg2, arg3, arg4) char *error_str; char *cont_str; int num; object arg1; object arg2; object arg3; object arg4; */
+/* /\* error.c:184:OF *\/ extern void FEerror (char *s, int num, ... ); /\* (s, num, arg1, arg2, arg3, arg4) char *s; int num; object arg1; object arg2; object arg3; object arg4; *\/ */
+/* /\* error.c:203:OF *\/ extern void FEwrong_type_argument (object type, object value); /\* (type, value) object type; object value; *\/ */
+/* /\* error.c:210:OF *\/ extern void FEtoo_few_arguments (object *base, object *top); /\* (base, top) object *base; object *top; *\/ */
+/* /\* error.c:219:OF *\/ extern void FEtoo_few_argumentsF (object args); /\* (args) object args; *\/ */
+/* /\* error.c:227:OF *\/ extern void FEtoo_many_arguments (object *base, object *top); /\* (base, top) object *base; object *top; *\/ */
+/* /\* error.c:234:OF *\/ extern void FEtoo_many_argumentsF (object args); /\* (args) object args; *\/ */
+/* /\* error.c:247:OF *\/ extern void FEunexpected_keyword (object key); /\* (key) object key; *\/ */
+/* /\* error.c:258:OF *\/ extern void FEinvalid_form (char *s, object form); /\* (s, form) char *s; object form; *\/ */
+/* /\* error.c:266:OF *\/ extern void FEunbound_variable (object sym); /\* (sym) object sym; *\/ */
+/* /\* error.c:273:OF *\/ extern void FEinvalid_variable (char *s, object obj); /\* (s, obj) char *s; object obj; *\/ */
+/* /\* error.c:280:OF *\/ extern void FEundefined_function (object fname); /\* (fname) object fname; *\/ */
+/* /\* error.c:287:OF *\/ extern void FEinvalid_function (object obj); /\* (obj) object obj; *\/ */
+/* /\* error.c:297:OF *\/ extern object CEerror (char *error_str, char *cont_str, int num, object arg1, object arg2, object arg3, object arg4); /\* (error_str, cont_str, num, arg1, arg2, arg3, arg4) char *error_str; char *cont_str; int num; object arg1; object arg2; object arg3; object arg4; *\/ */
 /* error.c:330:OF */ extern object fSihs_top (void); /* () */
 /* error.c:337:OF */ extern object fSihs_fun (object x0); /* (x0) object x0; */
 /* error.c:346:OF */ extern object fSihs_vs (object x0); /* (x0) object x0; */
@@ -208,7 +211,7 @@ typedef int (*FUNC)();
 /* eval.c:1191:OF */ extern object fLeval (object x0); /* (x0) object x0; */
 /* eval.c:1203:OF */ extern void Levalhook (void); /* () */
 /* eval.c:1269:OF */ extern void Lconstantp (void); /* () */
-/* eval.c:1271:OF */ extern object fLconstantp (object x0); /* (x0) object x0; */
+/* eval.c:1271:OF */ extern object fLconstantp (object x0,...); /* (x0) object x0; */
 /* eval.c:1293:OF */ extern object ieval (object x); /* (x) object x; */
 /* eval.c:1309:OF */ extern object ifuncall1 (object fun, object arg1); /* (fun, arg1) object fun; object arg1; */
 /* eval.c:1328:OF */ extern object ifuncall2 (object fun, object arg1, object arg2); /* (fun, arg1, arg2) object fun; object arg1; object arg2; */
@@ -475,28 +478,28 @@ typedef void (*funcvoid)(void);
 /* structure.c:326:OF */ extern void siLlist_nth (void); /* () */
 /* structure.c:439:OF */ extern void gcl_init_structure_function (void); /* () */
 /* toplevel.c:211:OF */ extern void gcl_init_toplevel (void); /* () */
-/* typespec.c:38:OF */ extern void check_type_integer (object *p); /* (p) object *p; */
-/* typespec.c:47:OF */ extern void check_type_non_negative_integer (object *p); /* (p) object *p; */
-/* typespec.c:65:OF */ extern void check_type_rational (object *p); /* (p) object *p; */
-/* typespec.c:75:OF */ extern void check_type_float (object *p); /* (p) object *p; */
-/* typespec.c:94:OF */ extern void check_type_or_rational_float (object *p); /* (p) object *p; */
-/* typespec.c:104:OF */ extern void check_type_number (object *p); /* (p) object *p; */
-/* typespec.c:123:OF */ extern void check_type_character (object *p); /* (p) object *p; */
-/* typespec.c:139:OF */ extern void check_type_symbol (object *p); /* (p) object *p; */
-/* typespec.c:146:OF */ extern void check_type_or_symbol_string (object *p); /* (p) object *p; */
-/* typespec.c:153:OF */ extern void check_type_or_string_symbol (object *p); /* (p) object *p; */
-/* typespec.c:170:OF */ extern void check_type_package (object *p); /* (p) object *p; */
-/* typespec.c:177:OF */ extern void check_type_string (object *p); /* (p) object *p; */
-/* typespec.c:191:OF */ extern void check_type_cons (object *p); /* (p) object *p; */
-/* typespec.c:198:OF */ extern void check_type_stream (object *p); /* (p) object *p; */
-/* typespec.c:205:OF */ extern void check_type_readtable (object *p); /* (p) object *p; */
-/* typespec.c:205:OF */ extern void check_type_readtable_no_default (object *p); /* (p) object *p; */
-/* typespec.c:213:OF */ extern void check_type_or_Pathname_string_symbol (object *p); /* (p) object *p; */
-/* typespec.c:225:OF */ extern void check_type_or_pathname_string_symbol_stream (object *p); /* (p) object *p; */
-/* typespec.c:236:OF */ extern void check_type_random_state (object *p); /* (p) object *p; */
-/* typespec.c:243:OF */ extern void check_type_hash_table (object *p); /* (p) object *p; */
-/* typespec.c:250:OF */ extern void check_type_array (object *p); /* (p) object *p; */
-/* typespec.c:284:OF */ extern void check_type (object x, int t); /* (x, t) object x; int t; */
+/* /\* typespec.c:38:OF *\/ extern void check_type_integer (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:47:OF *\/ extern void check_type_non_negative_integer (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:65:OF *\/ extern void check_type_rational (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:75:OF *\/ extern void check_type_float (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:94:OF *\/ extern void check_type_or_rational_float (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:104:OF *\/ extern void check_type_number (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:123:OF *\/ extern void check_type_character (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:139:OF *\/ extern void check_type_symbol (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:146:OF *\/ extern void check_type_or_symbol_string (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:153:OF *\/ extern void check_type_or_string_symbol (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:170:OF *\/ extern void check_type_package (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:177:OF *\/ extern void check_type_string (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:191:OF *\/ extern void check_type_cons (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:198:OF *\/ extern void check_type_stream (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:205:OF *\/ extern void check_type_readtable (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:205:OF *\/ extern void check_type_readtable_no_default (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:213:OF *\/ extern void check_type_or_Pathname_string_symbol (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:225:OF *\/ extern void check_type_or_pathname_string_symbol_stream (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:236:OF *\/ extern void check_type_random_state (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:243:OF *\/ extern void check_type_hash_table (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:250:OF *\/ extern void check_type_array (object *p); /\* (p) object *p; *\/ */
+/* /\* typespec.c:284:OF *\/ extern void check_type (object x, int t); /\* (x, t) object x; int t; *\/ */
 /* typespec.c:294:OF */ extern void Ltype_of (void); /* () */
 /* typespec.c:493:OF */ extern void gcl_init_typespec (void); /* () */
 /* typespec.c:497:OF */ extern void gcl_init_typespec_function (void); /* () */
@@ -1298,10 +1301,10 @@ int
 system_time_zone_helper(void);
 
 object
-call_proc_new(object,int setf,void **,int,object,va_list);
+call_proc_new(object,int setf,int pop_one_arg,void **,int,object,va_list);
 
 object 
-call_vproc_new(object,int setf,void *,object,va_list);
+call_vproc_new(object,int setf,int pop_one_arg,void *,object,va_list);
 
 void
 funcall_with_catcher(object, object);
@@ -1748,9 +1751,15 @@ cplus(object,object);
 object
 Icall_error_handler(object,object,int,...);
 
+object
+Icall_continue_error_handler(object,object,object,int,...);
+
 void *
 gcl_gmp_alloc(size_t);
 
+void
+init_gmp_rnd_state(__gmp_randstate_struct *);
+
 int
 my_plt(const char *,unsigned long *);
 
@@ -1766,6 +1775,23 @@ gcl_isnormal_double(double);
 int 
 gcl_isnormal_float(float);
 
+object
+powm_bbb(object,object,object);
+object
+powm_bfb(object,fixnum,object);
+object
+powm_fbb(fixnum,object,object);
+object
+powm_ffb(fixnum,fixnum,object);
+object
+powm_bbf(object,object,fixnum);
+object
+powm_bff(object,fixnum,fixnum);
+object
+powm_fbf(fixnum,object,fixnum);
+object
+powm_fff(fixnum,fixnum,fixnum);
+
 object
 find_init_name1(char *,unsigned);
 
@@ -1817,4 +1843,13 @@ gprof_cleanup(void);
 unsigned long
 ihash_equal1(object,int);
 
+object
+interactive_stream_p(object);
+
+void
+reinit_gmp(void);
+
+object
+macro_def_int(object);
+
 /* void call_after_gbc_hook(int); */
