@@ -1,5 +1,13 @@
 
 (IN-PACKAGE "SYSTEM") 
+(PROCLAIM
+    '(FTYPE (FUNCTION () T) lexical-binding-environment))
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T SEQIND T) T) prune-type))
+(PROCLAIM
+    '(FTYPE (FUNCTION (SEQIND T) T) SMALLNTHCDR))
+(PROCLAIM
+    '(FTYPE (FUNCTION (T SEQIND T T) T) BIGNTHCDR))
 (PROCLAIM
     '(FTYPE (FUNCTION (T) FIXNUM) INSTREAM-LINE S-DATA-SIZE
             S-DATA-LENGTH THE-START)) 
@@ -35,7 +43,7 @@
     '(FTYPE (FUNCTION (T T T) *) READ-INSPECT-COMMAND SHARP-S-READER)) 
 (PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) *) TRACE-CALL)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
+    '(FTYPE (FUNCTION (T T T) T) copy-tree-int copy-list-int
             SLOOP::LOOP-PARSE-ADDITIONAL-COLLECTIONS CONS-OP COMPLEX-OP
             ARRAY-OP SETF-EXPAND-1 LIST-MERGE-SORT WARN-VERSION
             SINGLE-OP RANGE-OP DEPOSIT-FIELD KEY-LIST MAKE-T-TYPE
@@ -64,7 +72,6 @@
     '(FTYPE (FUNCTION (T T T T *) T) PRINT-STACK-FRAME
             SLOOP::DEF-LOOP-INTERNAL MERGE)) 
 (PROCLAIM '(FTYPE (FUNCTION (T T T T T T *) T) ENCODE-UNIVERSAL-TIME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T *) T) UNIVERSAL-ERROR-HANDLER)) 
 (PROCLAIM
     '(FTYPE (FUNCTION NIL *) BREAK-CURRENT BREAK-MESSAGE
             SIMPLE-BACKTRACE)) 
@@ -84,14 +91,14 @@
             ALL-TRACE-DECLARATIONS SLOOP::SLOOP-TYPE-ERROR CLEANUP)) 
 (PROCLAIM
     '(FTYPE (FUNCTION (*) *) LOC BREAK-BDS BREAK-LOCAL BREAK-VS
-            BREAK-NEXT BREAK-PREVIOUS BREAK-QUIT SERROR::INF-SIGNAL
+            BREAK-NEXT BREAK-PREVIOUS BREAK-QUIT 
             INFO-ERROR DBL-BACKTRACE IHS-BACKTRACE
             SHOW-BREAK-VARIABLES)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (*) T) COPY-PPRINT-DISPATCH DBL-READ BREAK
+    '(FTYPE (FUNCTION (*) T) MAYBE-CLEAR-INPUT COPY-PPRINT-DISPATCH DBL-READ BREAK
             DESCRIBE-ENVIRONMENT SLOOP::PARSE-LOOP-DECLARE
             SLOOP::PARSE-LOOP-WITH DRIBBLE BREAK-LOCALS
-            SERROR::MAKE-ERROR-CONDITION YES-OR-NO-P Y-OR-N-P
+             YES-OR-NO-P Y-OR-N-P
             MAKE-S-DATA MAKE-INSTREAM VECTOR CURRENT-STEP-FUN NTP-OR
             NTP-AND STEP-NEXT STEP-INTO)) 
 (PROCLAIM
@@ -103,15 +110,16 @@
     '(FTYPE (FUNCTION (T *) *) FCEILING FROUND FFLOOR WRITE-TO-STRING
             ENSURE-DIRECTORIES-EXIST INFO PRINT-DOC BREAK-FUNCTION
             GET-SETF-METHOD-MULTIPLE-VALUE GET-SETF-METHOD
-            DECODE-UNIVERSAL-TIME READ-FROM-STRING STEPPER APROPOS
+            DECODE-UNIVERSAL-TIME READ-FROM-STRING STEPPER 
             FTRUNCATE PPRINT-DISPATCH SHOW-INFO NLOAD APROPOS-DOC)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T) T) TYPE-OF CLASS-OF NON-LOGICAL-PATHNAME-P DO-F SLOOP::POINTER-FOR-COLLECT
+    '(FTYPE (FUNCTION (T) T) copy-list copy-tree seqindp proper-listp sequencep short-float-p long-float-p ratiop
+	    first second third fourth fifth sixth seventh eighth ninth tenth
+	    improper-consp TYPE-OF CLASS-OF NON-LOGICAL-PATHNAME-P DO-F SLOOP::POINTER-FOR-COLLECT
 	    sequence-type-element-type  sequence-type-element-type-int
 	    sequence-type-length-type sequence-type-length-type-int
             SLOOP::LOOP-LET-BINDINGS SLOOP::LOOP-COLLECT-KEYWORD-P
-            SERROR::|TOO-MANY-ARGUMENTS-tester|
-            SERROR::|TOO-FEW-ARGUMENTS-tester| COERCE-TO-STANDARD-CLASS
+             COERCE-TO-STANDARD-CLASS
             NON-STANDARD-BASE-CHAR-P NON-KEYWORD-SYMBOL-P
             IS-STANDARD-CLASS-SYMBOL CONS-RECON CONS-TO-NIL CONS-ATM
             COMPLEX-RECON LOGNOT ISQRT ACOSH ASINH COSH ACOS ASIN
@@ -127,17 +135,7 @@
             SLOOP::AVERAGING-SLOOP-MACRO SLOOP::RETURN-SLOOP-MACRO
             SLOOP::REPEAT-SLOOP-MACRO SLOOP::SUBSTITUTE-SLOOP-BODY
             SLOOP::PARSE-LOOP-INITIALLY SLOOP::PARSE-NO-BODY
-            SLOOP::PARSE-LOOP SERROR::|UNDEFINED-FUNCTION-tester|
-            SERROR::|UNBOUND-VARIABLE-tester|
-            SERROR::|WRONG-TYPE-ARGUMENT-tester|
-            SERROR::|UNEXPECTED-KEYWORD-tester|
-            SERROR::|INVALID-FUNCTION-tester|
-            SERROR::|INVALID-VARIABLE-tester|
-            SERROR::|INVALID-FORM-tester| SERROR::|ERROR-tester|
-            SERROR::ERROR-CONDITION-P SERROR::ERROR-ERROR-HANDLER-ARGS
-            SERROR:ERROR-FORMAT-ARGS SERROR:ERROR-CONTINUE-STRING
-            SERROR::ERROR-FUNCTION SERROR:ERROR-STRING
-            SERROR:ERROR-NAME NRECONSTRUCT-TYPE NRECONSTRUCT-TYPE-INT INTERPRETED-FUNCTION-P
+            SLOOP::PARSE-LOOP NRECONSTRUCT-TYPE NRECONSTRUCT-TYPE-INT INTERPRETED-FUNCTION-P
             ARRAY-RECON ARRAY-ATM PRINT-SYMBOL-APROPOS ABS PROVIDE
             INFO-NODE-FROM-POSITION INFO-GET-FILE INFO-GET-TAGS
             INSPECT-STRUCTURE INSPECT-ARRAY INSPECT-VECTOR
@@ -145,7 +143,7 @@
             INSPECT-CHARACTER INSPECT-PACKAGE INSPECT-SYMBOL
             FREEZE-DEFSTRUCT INSERT-BREAK-POINT INSTREAM-P
             INSTREAM-STREAM-NAME INSTREAM-STREAM ARRAY-DIMENSIONS
-            SERROR::|SUBSCRIPT-OUT-OF-BOUNDS-tester| SEQTYPE
+            SEQTYPE
             SINGLE-RECON SINGLE-ATM RANGE-RECON SIMPLE-ARRAY-P
             RESOLVE-TYPE FIND-STANDARD-CLASS FUNCTION-IDENTIFIERP
             DISTRIBUTE-COMPLEX BASE-CHAR-P FIND-ALL-SYMBOLS TANH SINH
@@ -163,14 +161,14 @@
             GET-NEXT-VISIBLE-FUN GET-INSTREAM TYPECASE-ERROR-STRINGS
             VECTOR-POP BEST-ARRAY-ELEMENT-TYPE CHECK-DECLARATIONS
             CHECK-TRACE-SPEC IHS-NOT-INTERPRETED-ENV IHS-VISIBLE
-            SLOOP::SLOOP-SLOOP-MACRO SERROR::|WTA-tester| CLASS-NAME
+            SLOOP::SLOOP-SLOOP-MACRO CLASS-NAME
             NTP-TO-NIL STANDARD-RECON STANDARD-ATM STRUCTURE-RECON
             STRUCTURE-ATM NTP-LOAD NTP-CLEAN NTP-NOT NPROCESS-TYPE
             CLASS-PRECEDENCE-LIST CLASSP EXTENDED-CHAR-P PHASE ATANH
             CLEAR-SEARCH-LIST IDESCRIBE SHOW-BREAK-POINT SHORT-NAME
             SHOW-ENVIRONMENT ADD-TO-HOTLIST)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T *) T) SLOOP::LOOP-ADD-TEMPS CONCATENATE
+    '(FTYPE (FUNCTION (T *) T) UNIVERSAL-ERROR-HANDLER SLOOP::LOOP-ADD-TEMPS CONCATENATE
             NORMALIZE-TYPE BREAK-LEVEL WARN FILE-SEARCH
             INTEGER-RANGE-FIXUP INFO-SEARCH SBIT ARRAY-ROW-MAJOR-INDEX
             ARRAY-IN-BOUNDS-P REMOVE-DUPLICATES DELETE-DUPLICATES
@@ -181,7 +179,8 @@
 (PROCLAIM
     '(FTYPE (FUNCTION (T T) *) FIND-DOC NEW-SEMI-COLON-READER NEWLINE)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) ordered-intersection ordered-intersection-eq subtypep1 copy-type SLOOP::LOGXOR-SLOOP-COLLECT
+    '(FTYPE (FUNCTION (T T) T) tp-error nthcdr nth tp-mod improper-consp-int ordered-intersection 
+	    ordered-intersection-eq subtypep1 copy-type SLOOP::LOGXOR-SLOOP-COLLECT
             SLOOP::COLLATE-SLOOP-COLLECT SLOOP::COUNT-SLOOP-COLLECT
             NORMALIZE-TYPE-INT CONS^ CONS-LOAD COMPLEX-LOAD COERCE
             LOGTEST LOGORC2 LOGORC1 LOGANDC2 LOGANDC1 LOGNOR LOGNAND
