@@ -435,7 +435,7 @@ Use ALLOCATE to expand the space.",
 }
 
 object
-make_cons(object a, object d)
+make_cons1(object a, object d)
 {
 	 object obj;
 	 char *p;
@@ -912,7 +912,7 @@ set_maxpage(void) {
     maxpage=page(heap_end);
     memory_protect(sgc_enabled ? 1 : 0);
   }
-  if (~(-MAXPAGE) != MAXPAGE-1) error("MAXPAGE must be power of 2");
+/*   if (~(-MAXPAGE) != MAXPAGE-1) error("MAXPAGE must be power of 2"); */
   /* FIXME ensure core_end in range for type_map reference below.  CM */
   if (core_end)
     bzero(&sgc_type_map[ page(core_end)],MAXPAGE- page(core_end));
@@ -930,7 +930,8 @@ gcl_init_alloc(void) {
   long i;
 #ifdef GCL_GPROF
    extern void *GCL_GPROF_START;
-   unsigned textpage=2*((void *)&etext-(void *)&GCL_GPROF_START)/PAGESIZE;
+   long textpage=2*((void *)&etext-(void *)&GCL_GPROF_START)/PAGESIZE,t1=2*((void *)&etext-(void *)GCL_GPROF_START)/PAGESIZE;
+   textpage=t1>0 && (textpage<0 || t1<textpage) ? t1 : textpage;
 #endif
   
   if (gcl_alloc_initialized) return;
@@ -1329,6 +1330,7 @@ DEFUN_NEW("GET-HOLE-SIZE",object,fSget_hole_size,SI
 
 static unsigned long start,end,gprof_on;
 static void *initial_monstartup_pointer;
+void *old_monstartup_pointer=NULL;
 
 void
 gprof_cleanup(void) {
@@ -1665,9 +1667,8 @@ free(void *ptr)
 			*p = Scdr(pp);
 #ifdef GCL_GPROF
 			if (initial_monstartup_pointer==ptr) {
+			  old_monstartup_pointer=initial_monstartup_pointer;
 			  initial_monstartup_pointer=NULL;
-			  if (core_end-heap_end>=sizeof(ptr))
-			    *(void **)heap_end=ptr;
 			}
 #endif
 			return ;
@@ -1675,8 +1676,15 @@ free(void *ptr)
 #ifdef NOFREE_ERR
 	return ;
 #else	
-	if (raw_image==FALSE || core_end-heap_end<sizeof(ptr) || ptr!=*(void **)heap_end)
-	  FEerror("free(3) error.",0);
+#ifdef GCL_GPROF
+	if (raw_image==FALSE || core_end-heap_end<sizeof(ptr) || ptr!=old_monstartup_pointer) 
+#endif
+	  {
+	    static void *old_ptr;
+	    if (old_ptr==ptr) return;
+	    old_ptr=ptr;
+	    FEerror("free(3) error.",0);
+	  }
 	return;
 #endif	
 }
