@@ -141,17 +141,17 @@ fScheck_bounds_bounds(object x, int i)
     }
 }
 
-DEFUNO_NEW("SVREF", object, fLsvref, LISP, 2, 2,
-      ONE_VAL, OO, IO, OO,OO,void,Lsvref,(object x,fixnum i),
-      "For array X and index I it returns (aref x i) ")
-{
- if (type_of(x)==t_vector
-     && (enum aelttype)x->v.v_elttype == aet_object
-     && x->v.v_dim > i)
-   RETURN1(x->v.v_self[i]);
- if (x->v.v_dim > i) illegal_index(x,make_fixnum(i));
- FEerror("Bad simple vector ~a",1,x);
+DEFUN_NEW("SVREF",object,fLsvref,LISP,2,2,ONE_VAL,OO,IO,OO,OO,(object x,fixnum i),"For array X and index I it returns (aref x i) ") {
+
+ if (type_of(x)==t_vector && (enum aelttype)x->v.v_elttype == aet_object) {
+     if (x->v.v_dim > i)
+       RETURN1(x->v.v_self[i]);
+     else
+       TYPE_ERROR(make_fixnum(i),list(3,sLinteger,make_fixnum(0),make_fixnum(x->v.v_dim)));
+ } else
+   TYPE_ERROR(x,sLsimple_vector);
  return(Cnil);
+
 }
     
 DEFUNO_NEW("ROW-MAJOR-AREF", object, fLrow_major_aref, LISP, 2, 2,
@@ -234,13 +234,11 @@ DEFUN_NEW("ASET1", object, fSaset1, SI, 3, 3, NONE, OO, IO, OO,OO,(object x, fix
       break;
     case aet_bit:
       i +=  BV_OFFSET(x);
-    AGAIN_BIT: 
       ASSURE_TYPE(val,t_fixnum);
       {int v = Mfix(val);
        if (v == 0) CLEAR_BITREF(x,i);
        else if (v == 1) SET_BITREF(x,i);
-       else {val= fSincorrect_type(val,sLbit);
-	     goto AGAIN_BIT;}
+       else TYPE_ERROR(val,sLbit);
        break;}
     case aet_fix:
     case aet_nnfix:
@@ -370,7 +368,8 @@ DEFUNO_NEW("SVSET", object, fSsvset, SI, 3, 3, NONE, OO, IO, OO,
        OO,void,siLsvset,(object x,fixnum i,object val),"")
 { if (TYPE_OF(x) != t_vector
       || DISPLACED_TO(x) != Cnil)
-    Wrong_type_error("simple array",0);
+  TYPE_ERROR(x,sLsimple_vector);
+/*     Wrong_type_error("simple array",0); */
   if (i > x->v.v_dim)
     { FEerror("out of bounds",0);
     }
@@ -705,13 +704,12 @@ FFN(Larray_displacement)(void) {
 static void
 displace(object from_array, object dest_array, int offset)
 {
-  enum aelttype typ;
+  enum aelttype typ,typ1;
   IisArray(from_array);
   IisArray(dest_array);
   typ =Iarray_element_type(from_array);
-  if (typ != Iarray_element_type(dest_array))
-    { Wrong_type_error("same element type",0);
-    }
+  if (typ != (typ1=Iarray_element_type(dest_array)))
+     TYPE_ERROR(from_array,list(2,sLarray,*aet_types[typ1].namep));
   if (offset + from_array->a.a_dim > dest_array->a.a_dim)
     { FEerror("Destination array too small to hold other array",0);
     }
@@ -938,13 +936,14 @@ gset(void *p1, void *val, int n, int typ)
    */
 
 DEFUN_NEW("COPY-ARRAY-PORTION",object,fScopy_array_portion,SI,4,
-      5,NONE,OO,OI,IO,OO,(object x,object y,fixnum i1,fixnum i2,object n1o),
+      5,NONE,OO,OO,OO,OO,(object x,object y,object o1,object o2,object n1o),
    "Copy elements from X to Y starting at x[i1] to x[i2] and doing N1 \
 elements if N1 is supplied otherwise, doing the length of X - I1 \
 elements.  If the types of the arrays are not the same, this has \
 implementation dependent results.")
 { enum aelttype typ1=Iarray_element_type(x);
   enum aelttype typ2=Iarray_element_type(y);
+  fixnum i1=fix(o1),i2=fix(o2);
   int n1=fix(n1o),nc;
   if (VFUN_NARGS==4)
     { n1 = x->v.v_dim - i1;}
@@ -1061,21 +1060,9 @@ DEFUNO_NEW("FILL-POINTER-SET",object,fSfill_pointer_set,SI,2,2,
   return make_fixnum(0);
 }
 
-DEFUNO_NEW("FILL-POINTER",object,fLfill_pointer,LISP,1,1,NONE,OO,
-       OO,OO,OO,void,Lfill_pointer,(object x),"")
-{
-  if (!(TS_MEMBER(type_of(x),TS(t_vector)|
-		    TS(t_bitvector)|
-		    TS(t_string))))
-    goto no_fillp;
-  if (x->v.v_hasfillp == 0)
-    { goto no_fillp;}
-  return make_fixnum(x->v.v_fillp) ;
-
- no_fillp:
-  FEwrong_type_argument(sLvector,x);
-  return make_fixnum(0);
-} 
+DEFUN_NEW("FILL-POINTER-INTERNAL",object,fSfill_pointer_internal,SI,1,1,NONE,OO,OO,OO,OO,(object x),"") {
+  RETURN1(make_fixnum(x->v.v_fillp));
+}
 
 DEFUN_NEW("ARRAY-HAS-FILL-POINTER-P",object,
       fLarray_has_fill_pointer_p,LISP,1,1,NONE,OO,OO,OO,OO,(object x),"")
@@ -1136,24 +1123,24 @@ DEFUNO_NEW("DISPLACED-ARRAY-P",object,fSdisplaced_array_p,SI,1,
   return (x->a.a_displaced == Cnil ? Cnil : sLt);
 }
 
-DEFUNO_NEW("ARRAY-RANK",object,fLarray_rank,LISP,1,1,NONE,OO,OO,OO,
-       OO,void,Larray_rank,(object x),"")
-{ if (type_of(x) == t_array)
-    return make_fixnum(x->a.a_rank);
+DEFUN_NEW("ARRAY-RANK",object,fLarray_rank,LISP,1,1,NONE,OO,OO,OO,OO,(object x),"") { 
+  if (type_of(x) == t_array)
+    RETURN1(make_fixnum(x->a.a_rank));
   IisArray(x);
-  return make_fixnum(1);
+  RETURN1(make_fixnum(1));
 }
 
-DEFUNO_NEW("ARRAY-DIMENSION",object,fLarray_dimension,LISP,2,2,
-       NONE,OO,IO,OO,OO,void,Larray_dimension,(object x,fixnum i),"")
-{ 
-  if (type_of(x) == t_array)
-   {  if ((unsigned int)i >= x->a.a_rank)
-	FEerror("Index ~a out of bounds for array-dimension",1
-		,make_fixnum(i));
-      else { return make_fixnum(x->a.a_dims[i]);}}
-   IisArray(x);
-   return make_fixnum(x->v.v_dim);
+DEFUN_NEW("ARRAY-DIMENSION",object,fLarray_dimension,LISP,2,2,NONE,OO,IO,OO,OO,(object x,fixnum i),"") { 
+
+  if (type_of(x) == t_array) {  
+    if ((unsigned int)i >= x->a.a_rank)
+      TYPE_ERROR(make_fixnum(i),list(3,sLinteger,make_fixnum(0),make_fixnum(x->a.a_rank)));
+    else { 
+      RETURN1(make_fixnum(x->a.a_dims[i]));
+    }
+  }
+  IisArray(x);
+  RETURN1(make_fixnum(x->v.v_dim));
 }
 #ifdef STATIC_FUNCTION_POINTERS
 object
@@ -1253,15 +1240,11 @@ DEFUNO_NEW("REPLACE-ARRAY",object,fSreplace_array,SI,2,2,NONE,
   return old;
 }
 
-DEFUN_NEW("ARRAY-TOTAL-SIZE",object,fLarray_total_size,LISP,1,1,
-       NONE,OO,OO,OO,OO,(object x),"")
-{ x = IisArray(x);
-  return make_fixnum(x->a.a_dim);
+DEFUN_NEW("ARRAY-TOTAL-SIZE",object,fLarray_total_size,LISP,1,1,NONE,OO,OO,OO,OO,(object x),"") { 
+  x = IisArray(x);
+  RETURN1(make_fixnum(x->a.a_dim));
 }
 
-
-
-
 DEFUN_NEW("ASET-BY-CURSOR",object,fSaset_by_cursor,SI,3,3,
        NONE,OO,OO,OO,OO,(object array,object val,object cursor),"")
 {
