@@ -361,7 +361,9 @@ SEARCH_DECLARE:
 		} else if (optional[i].opt_svar == v) {
 			optional[i].opt_svar_spp = Ct;
 			special_processed = TRUE;
-		}
+		} else if (optional[i].opt_init == v)
+		  special_processed = TRUE;
+		
 	if (rest_flag && rest->rest_var == v) {
 		rest->rest_spp = Ct;
 		special_processed = TRUE;
@@ -373,12 +375,14 @@ SEARCH_DECLARE:
 		} else if (keyword[i].key_svar == v) {
 			keyword[i].key_svar_spp = Ct;
 			special_processed = TRUE;
-		}
+		} else if (keyword[i].key_init == v)
+		  special_processed = TRUE;
 	for (i = 0;  i < naux;  i++)
 		if (aux[i].aux_var == v) {
 			aux[i].aux_spp = Ct;
 			special_processed = TRUE;
-		}
+		} else if (aux[i].aux_init == v)
+		  special_processed = TRUE;
 	if (special_processed)
 		continue;
 	/*  lex_special_bind(v);  */
@@ -1078,7 +1082,7 @@ set_key_struct(struct key *ks, object data)
 {int i=ks->n;
  while (--i >=0)
    {ks->keys[i].o =   data->cfd.cfd_self[ ks->keys[i].i ];
-    if (ks->defaults != (iobject *)Cstd_key_defaults)
+    if (ks->defaults != (void *)Cstd_key_defaults)
       {int m=ks->defaults[i].i;
         ks->defaults[i].o=
 	  (m==-2 ? Cnil :
