@@ -93,12 +93,10 @@ object sSAbreak_stepA;
 static void
 quick_call_sfun(object fun)
 { DEBUG_AVMA
-  int i=fun->sfn.sfn_argd,n=SFUN_NARGS(i);
+    int i=fun->sfn.sfn_argd,n=SFUN_NARGS(i),mv=CMVFUNP(fun);
   enum ftype restype;
   object *x,res=OBJNULL,*base;
-  object *temp_ar=ZALLOCA(n*sizeof(object));
-/*   i=fun->sfn.sfn_argd; */
-/*   n=SFUN_NARGS(i); */
+  object *temp_ar=ZALLOCA((n+1)*sizeof(object));
   base = vs_base;
   if (n != vs_top - base)
     {check_arg_failed(n);}
@@ -106,22 +104,28 @@ quick_call_sfun(object fun)
   SFUN_START_ARG_TYPES(i);
   /* for moment just support object and int */
 #define COERCE_ARG(a,type)  (type==f_object ? a : (type==f_fixnum ? (object)(fix(a)) : (object)otoi(a)))
-  if (i==0)
-    x=vs_base;
-  else
-    {int j;
-     x=temp_ar;
-     for (j=0; j<n ; j++)
-       {enum ftype typ=SFUN_NEXT_TYPE(i);
-	x[j]=COERCE_ARG(vs_base[j],typ);}}
-  SET_TO_APPLY(res,fun->sfn.sfn_self,n,x);
+  x=temp_ar;
+  if (mv) 
+    *x++=(void *)(base+1);
+  if (i==0) {
+    memcpy(x,vs_base,n*sizeof(*x));
+    x+=n;
+  } else {
+    int j;
+    for (j=0;j<n;j++) {
+      enum ftype typ=SFUN_NEXT_TYPE(i);
+      *x++=COERCE_ARG(vs_base[j],typ);
+    }
+  }
+  SET_TO_APPLY(res,fun->sfn.sfn_self,x-temp_ar,temp_ar);
   base[0]=
     (restype==f_object ?  res :
      (restype==f_fixnum ? make_fixnum((long)res) :
       (restype==f_integer ? make_integer((GEN)res) :
        (object) (FEerror("Bad result type",0),Cnil))));
   vs_base = base;
-  vs_top=base+1;
+  if (!mv)
+    vs_top=base+1;
   CHECK_AVMA;
   return;}
 
@@ -148,8 +152,16 @@ call_vfun(object fun)
   if (n > fun->vfn.vfn_maxargs)
     {FEtoo_many_arguments(base,vs_top); return;}
   VFUN_NARGS = n;
-  SET_TO_APPLY(base[0],fun->sfn.sfn_self,n,base);
-  vs_top=(vs_base=base)+1;
+  if (CMVFUNP(fun)) {
+    object *tmp=ZALLOCA((n+1)*sizeof(object));
+    memcpy(tmp+1,base,n*sizeof(*base));
+    tmp[0]=(object)(base+1);
+    SET_TO_APPLY(base[0],fun->sfn.sfn_self,n+1,tmp);
+    vs_base=base;
+  } else {
+    SET_TO_APPLY(base[0],fun->sfn.sfn_self,n,base);
+    vs_top=(vs_base=base)+1;
+  }
   CHECK_AVMA;
   return;
 }
@@ -1146,13 +1158,16 @@ call_applyhook(object fun)
 	super_funcall(ah);
 }
 
-DEFUNO_NEW("FUNCALL",object,fLfuncall,LISP
+DEFUNOM_NEW("FUNCALL",object,fLfuncall,LISP
        ,1,MAX_ARGS,NONE,OO,OO,OO,OO,void,Lfuncall,(object fun,...),"") { 
 
   va_list ap;
   object *new;
   int i,n = VFUN_NARGS-1;
 
+  if (type_of(fun)==t_symbol && 
+      (fun->s.s_mflag || fun->s.s_sfdef!=NOT_SPECIAL))
+    UNDEFINED_FUNCTION(fun);
   if (n>=65) FEerror("arg limit exceeded",0);
   new=ZALLOCA(n*sizeof(*new));
 /*   wipe_stack(&n); */
@@ -1164,10 +1179,10 @@ DEFUNO_NEW("FUNCALL",object,fLfuncall,LISP
 }
 
 
-DEFUNO_NEW("APPLY",object,fLapply,LISP
+DEFUNOM_NEW("APPLY",object,fLapply,LISP
        ,2,MAX_ARGS,NONE,OO,OO,OO,OO,void,Lapply,(object fun,...),"")
 {	int m,n=VFUN_NARGS;
-	object list;
+	object olist;
 	object buf[MAX_ARGS];
 	object *base=buf;
 	va_list ap;
@@ -1177,12 +1192,12 @@ DEFUNO_NEW("APPLY",object,fLapply,LISP
 	  {*base++ = va_arg(ap,object);
 	 }
 	m = n-2;
-	list = va_arg(ap,object);
+	olist = va_arg(ap,object);
 	va_end(ap);
-	while (!endp(list))
+	while (!endp(olist))
 	  { if (m >= MAX_ARGS) FEerror(" Lisps arglist maximum surpassed",0);
-	    *base++ = Mcar(list);
-	    list = Mcdr(list);
+	    *base++ = Mcar(olist);
+	    olist = Mcdr(olist);
 	    m++;}
 	return IapplyVector(fun,m,buf);
       }
@@ -1268,7 +1283,7 @@ LFD(Lapplyhook)(void)
 }
 
 DEFUNO_NEW("CONSTANTP",object,fLconstantp,LISP
-       ,1,1,NONE,OO,OO,OO,OO,void,Lconstantp,(object x0),"")
+       ,1,2,NONE,OO,OO,OO,OO,void,Lconstantp,(object x0,...),"")
 {
 	enum type x;
 	/* 1 args */
@@ -1477,12 +1492,15 @@ fcalln_vfun(object first,va_list vl)
 }
 
 object 
-fcalln1(object first,...)
-{  va_list ap;
-   object fun=fcall.fun;
-   DEBUG_AVMA
-   va_start(ap,first);
-   if(type_of(fun)==t_cfun)
+fcalln1(object first,...) {  
+
+  va_list ap;
+  object fun=fcall.fun;
+  enum type tp;
+  DEBUG_AVMA
+  va_start(ap,first);
+  tp=fun==OBJNULL ? -1 : type_of(fun);
+  if(tp==t_cfun)
      {object *base=vs_top,*old_base=base;
       int i=fcall.argd;
       vs_base=base;
@@ -1511,9 +1529,9 @@ fcalln1(object first,...)
       CHECK_AVMA;
       return(vs_base[0]);
     }
-   if(type_of(fun)==t_cclosure)
+   if(tp==t_cclosure)
      return(fcalln_cclosure(first,ap));
-   if(type_of(fun)==t_vfun)
+   if(tp==t_vfun && !fun->vfn.vfn_mv)
      return(fcalln_vfun(first,ap));
    return(fcalln_general(first,ap));
   va_end(ap);
