@@ -59,12 +59,25 @@ void initialize_process();
 
 #ifdef _WIN32
 
+#ifdef WITH_WINMAIN
+#  include <windows.h>
+#endif
+
 extern void init_shared_memory (void);
+int is_shared_memory_initialised = FALSE;
 
 #  include <fcntl.h>
 
 #endif
 
+#ifdef HAVE_TK
+
+#  include <tcl.h>
+#  include <tk.h>
+Tcl_Interp *tcl_interpreter;
+
+#endif
+
 #define LISP_IMPLEMENTATION_VERSION "April 1994"
 
 #define EXTRA_BUFSIZE 8
@@ -128,7 +141,9 @@ clear_c_stack(VOL unsigned n) {
 unsigned long cssize      = 0;
 
 int
-main(int argc, char **argv, char **envp) {
+gcl_main(int argc, char **argv, char **envp)
+{
+
 #if defined ( BSD ) && defined ( RLIMIT_STACK )
     struct rlimit rl;
 #endif
@@ -151,21 +166,35 @@ main(int argc, char **argv, char **envp) {
 	}
 #endif
 
-    install_segmentation_catcher();
+#ifdef GCL_GPROF
+	{
+	  extern void *old_monstartup_pointer;
+	  old_monstartup_pointer=NULL;
+	}
+#endif
 
+    install_segmentation_catcher();
     set_maxpage();
 
 #ifdef RECREATE_HEAP
     RECREATE_HEAP
 #endif
+
     setbuf(stdin, stdin_buf); 
     setbuf(stdout, stdout_buf);
+
 #ifdef _WIN32
+
     _fmode = _O_BINARY;
-    _setmode( _fileno( stdin ),  _O_BINARY );
-    _setmode( _fileno( stdout ), _O_BINARY );
-    _setmode( _fileno( stderr ), _O_BINARY );
+    _setmode ( _fileno ( stdin ),  _O_BINARY );
+    _setmode ( _fileno ( stdout ), _O_BINARY );
+    _setmode ( _fileno ( stderr ), _O_BINARY );
+    
+    /* Don't initialise shared memory until after the Heap is recreated.*/
+    init_shared_memory();
+
 #endif
+
     ARGC = argc;
     ARGV = argv;
 #ifdef UNIX
@@ -175,6 +204,7 @@ main(int argc, char **argv, char **envp) {
 #else
 	kcl_self = argv[0];
 #endif
+
 #ifdef FIX_FILENAME
     {
         int n = strlen ( kcl_self );
@@ -327,7 +357,8 @@ main(int argc, char **argv, char **envp) {
 #ifdef INIT_CORE_END
             INIT_CORE_END
 #endif			  
-                alloc_page(-(holepage + nrbpage));
+            alloc_page(-(holepage + nrbpage));
+
         }
 
         initflag = FALSE;
@@ -352,7 +383,27 @@ main(int argc, char **argv, char **envp) {
 #ifdef HAVE_READLINE
         gcl_init_readline_function();
 #endif
+	reinit_gmp();
+#ifdef HAVE_TK
+#  ifdef _WIN32
+	Tcl_FindExecutable ( argv[0] );
+	tcl_interpreter = Tcl_CreateInterp();
+#  else
+	tcl_interpreter = Tcl_CreateInterp();
+	if ( Tcl_AppInit ( tcl_interpreter ) != TCL_OK ) {
+	  fprintf(stderr, "Tcl_AppInit failed: %s\n", interp->result);
+	}
+#  endif
+#endif
+
     again:
+
+#ifdef HAVE_TK
+        if ( Tk_GetNumMainWindows() > 0 ) {
+            Tcl_DoOneEvent(0);
+        }
+#endif
+
         super_funcall(sStop_level);
         if (type_of(sSAmultiply_stacksA->s.s_dbind)==t_fixnum) {
             multiply_stacks(fix(sSAmultiply_stacksA->s.s_dbind));
@@ -400,6 +451,177 @@ main(int argc, char **argv, char **envp) {
 
 }
 
+#ifdef WITH_WINMAIN
+
+#  define MAX_CONSOLE_LINES 500
+
+void SetupConsole ( void )
+{
+    /* allocate a console for this app */
+    AllocConsole ();
+
+    /* Set the console up */
+    {
+        HANDLE hStdOut = GetStdHandle ( STD_OUTPUT_HANDLE );
+        int    fdOut   = _open_osfhandle ( hStdOut, _O_TEXT );
+        
+        HANDLE hStdIn  = GetStdHandle ( STD_INPUT_HANDLE );
+        int    fdIn    = _open_osfhandle ( hStdIn,  _O_TEXT );
+
+        HANDLE hStdErr = GetStdHandle ( STD_ERROR_HANDLE );
+        int    fdErr   = _open_osfhandle ( hStdErr, _O_TEXT );
+
+        CONSOLE_SCREEN_BUFFER_INFO coninfo;
+        FILE *fp;
+
+        /* set the screen buffer to be big enough to let us scroll text */
+        GetConsoleScreenBufferInfo ( hStdOut, &coninfo );
+        coninfo.dwSize.Y = MAX_CONSOLE_LINES;
+        SetConsoleScreenBufferSize ( hStdOut, coninfo.dwSize);
+
+        /* redirect unbuffered std i/o to the console */
+        fp = _fdopen ( fdOut, "w" );
+        *stdout = *fp;
+        setvbuf ( stdout, NULL, _IONBF, 0 );
+
+        fp = _fdopen ( fdIn, "r" );
+        *stdin = *fp;
+        setvbuf ( stdin, NULL, _IONBF, 0 );
+
+        fp = _fdopen ( fdErr, "w" );
+        *stderr = *fp;
+        setvbuf ( stderr, NULL, _IONBF, 0 );
+    }
+}
+
+
+/* Borrowed from TK 8.4.2 */
+
+static void
+setargv ( int *argcPtr, char ***argvPtr )
+{
+    char *p, *arg, *argSpace;
+    char **argv;
+    int argc, size, inquote, copy, slashes;
+    LPTSTR cmdLine = GetCommandLine ();
+    
+    /*
+     * Precompute an overly pessimistic guess at the number of arguments
+     * in the command line by counting non-space spans.
+     */
+
+    size = 2;
+    for (p = cmdLine; *p != '\0'; p++) {
+	if ((*p == ' ') || (*p == '\t')) {	/* INTL: ISO space. */
+	    size++;
+	    while ((*p == ' ') || (*p == '\t')) { /* INTL: ISO space. */
+		p++;
+	    }
+	    if (*p == '\0') {
+		break;
+	    }
+	}
+    }
+    argSpace = (char *) malloc ( (unsigned) (size * sizeof (char *) + strlen ( cmdLine ) + 1 ) );
+    argv = (char **) argSpace;
+    argSpace += size * sizeof(char *);
+    size--;
+
+    p = cmdLine;
+    for (argc = 0; argc < size; argc++) {
+	argv[argc] = arg = argSpace;
+	while ((*p == ' ') || (*p == '\t')) {	/* INTL: ISO space. */
+	    p++;
+	}
+	if (*p == '\0') {
+	    break;
+	}
+
+	inquote = 0;
+	slashes = 0;
+	while (1) {
+	    copy = 1;
+	    while (*p == '\\') {
+		slashes++;
+		p++;
+	    }
+	    if (*p == '"') {
+		if ((slashes & 1) == 0) {
+		    copy = 0;
+		    if ((inquote) && (p[1] == '"')) {
+			p++;
+			copy = 1;
+		    } else {
+			inquote = !inquote;
+		    }
+                }
+                slashes >>= 1;
+            }
+
+            while (slashes) {
+		*arg = '\\';
+		arg++;
+		slashes--;
+	    }
+
+	    if ((*p == '\0')
+		    || (!inquote && ((*p == ' ') || (*p == '\t')))) { /* INTL: ISO space. */
+		break;
+	    }
+	    if (copy != 0) {
+		*arg = *p;
+		arg++;
+	    }
+	    p++;
+        }
+	*arg = '\0';
+	argSpace = arg + 1;
+    }
+    argv[argc] = NULL;
+
+    *argcPtr = argc;
+    *argvPtr = argv;
+}
+
+int APIENTRY
+WinMain ( HINSTANCE hInstance,
+	  HINSTANCE hPrevInstance,
+	  LPSTR lpszCmdLine,
+	  int nCmdShow )
+{
+    char **argv, **envp = NULL;
+    int argc;
+    int rv;
+    setargv ( &argc, &argv );
+    {
+        int index = 1;
+        int console = TRUE;
+        while ( argv[index] ) {
+	    if ( 0 == strcmp ( argv[index], "-noconsole" ) ) {
+	        console = FALSE;
+	    }
+	    index++;
+        }
+        if ( console ) {
+	  SetupConsole ();
+	} 
+    }
+    rv = gcl_main ( argc, argv, envp );
+    FreeConsole ();
+    return ( rv );
+}
+
+#else /* WITH_WINMAIN */
+
+int
+main(int argc, char **argv, char **envp)
+{
+  return gcl_main ( argc, argv, envp );
+}
+ 
+#endif /* WITH_WINMAIN */
+
+
 /* catch certain signals */
 void install_segmentation_catcher(void)
 {
@@ -434,7 +656,7 @@ error(char *s) {
   printf("\nUnrecoverable error: %s.\n", s);
   fflush(stdout);
 #ifdef UNIX
-  abort();
+  gcl_abort();
 #endif
 }
 
@@ -508,7 +730,7 @@ initlisp(void) {
 
         if ( NULL_OR_ON_C_STACK(&j) == 0
              || NULL_OR_ON_C_STACK(IM_FIX_BASE) == 0
-             || NULL_OR_ON_C_STACK(IM_FIX_BASE|IM_FIX_LIM) == 0
+             || NULL_OR_ON_C_STACK((IM_FIX_BASE|IM_FIX_LIM)) == 0
              || NULL_OR_ON_C_STACK(Cnil) != 0
              || (((unsigned long )core_end) !=0
                   && NULL_OR_ON_C_STACK(core_end) != 0))
@@ -682,7 +904,6 @@ FFN(siLargv)(void) {
       i >= ARGC)
     FEerror("Illegal argument index: ~S.", 1, vs_base[0]);
   vs_base[0] = make_simple_string(ARGV[i]);
-
 }
 
 #ifdef UNIX
@@ -701,8 +922,11 @@ FFN(siLgetenv)(void) {
   for (i = 0;  i < vs_base[0]->st.st_fillp;  i++)
     name[i] = vs_base[0]->st.st_self[i];
   name[i] = '\0';
-  if ((value = getenv(name)) != NULL)
-    {vs_base[0] = make_simple_string(value);
+  if ((value = getenv(name)) != NULL) {
+#ifdef _WIN32
+    fix_filename(NULL, value);
+#endif    
+    vs_base[0] = make_simple_string(value);
 #ifdef FREE_GETENV_RESULT
     free(value);
 #endif		
@@ -1037,10 +1261,22 @@ init_main(void) {
 #endif
   ADD_FEATURE("UNEXEC");
 
+#ifdef HAVE_XGCL
+  ADD_FEATURE("XGCL");
+#endif
+
 #ifdef HAVE_GNU_LD
   ADD_FEATURE("GNU-LD");
 #endif
   
+#ifdef HAVE_JAPI_H
+  ADD_FEATURE("JAPI-PRIMITIVES");
+#endif	 
+
+#ifdef HAVE_TK
+  ADD_FEATURE("TK-PRIMITIVES");
+#endif	 
+
   make_special("*FEATURES*",features);}
   
   make_si_function("SAVE-SYSTEM", siLsave_system);
