@@ -592,7 +592,7 @@ int fasload ( object faslfile )
         dprintf ( "About to symbol_value %x \n", data );
 
         if ( symbol_value(sLAload_verboseA) != Cnil ) {
-            printf("start address -T %x ", memory->cfd.cfd_start);
+            printf(" ;; start address -T %x ", memory->cfd.cfd_start);
         }
 	return ( memory->cfd.cfd_size );
 #endif
