@@ -46,7 +46,7 @@ License for more details.
 #ifdef STAND
 #include "include.h"
 
-#define FEerror(a...) do {fprintf(stderr,##a);exit(1);} while (0)
+#define FEerror(a...) do {fprintf(stderr,##a);gcl_abort();} while (0)
 #endif
 
 static void relocate_symbols(Elf32_Sym *sym,int nsyms,int nscns, int *init_address_ptr);
@@ -373,7 +373,7 @@ fasload(faslfile)
    vs_top = old_vs_top;
 
    if(symbol_value(sLAload_verboseA)!=Cnil)
-     printf("start address -T %p ",memory->cfd.cfd_start);
+     printf(" ;; start address -T %p ",memory->cfd.cfd_start);
    return(memory->cfd.cfd_size);
 
 #endif /* STAND */
