@@ -197,6 +197,9 @@ sgc_mark_object1(object x) {
     sgc_mark_cons(x->s.s_plist);});
     sgc_mark_object(x->s.s_gfdef);
     sgc_mark_object(x->s.s_dbind);
+    if (x->s.s_hpack!=Cnil && x->s.s_hpack->p.p_name==Cnil)
+      x->s.s_hpack=Cnil;
+/*       sgc_mark_object(x->s.s_hpack); */
     if (x->s.s_self == NULL)
       break;
     /* to do */
@@ -542,11 +545,13 @@ sgc_mark_object1(object x) {
   case t_random:
     if ((int)what_to_collect >= (int)t_contiguous) {
       SGC_MARK_MP(x->rnd.rnd_state._mp_seed);
+#if __GNU_MP_VERSION < 4 || __GNU_MP_VERSION_MINOR < 2
       if (x->rnd.rnd_state._mp_algdata._mp_lc) {
 	SGC_MARK_MP(x->rnd.rnd_state._mp_algdata._mp_lc->_mp_a);
 	if (!x->rnd.rnd_state._mp_algdata._mp_lc->_mp_m2exp) SGC_MARK_MP(x->rnd.rnd_state._mp_algdata._mp_lc->_mp_m);
 	SGC_MARK_CP(x->rnd.rnd_state._mp_algdata._mp_lc,sizeof(*x->rnd.rnd_state._mp_algdata._mp_lc));
       }
+#endif
     }
     break;
     
@@ -1476,7 +1481,7 @@ sgc_start(void) {
     
     {
       old_rb_start=rb_start;
-      if(!saving_system) {
+/*       if(!saving_system) */ {
 	new=alloc_relblock(((unsigned long)WSGC(tm))*PAGESIZE);
 	/* the above may cause a gc, shifting the relblock */
 	old_rb_start=rb_start;
