@@ -124,7 +124,14 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #endif
 #include <mach-o/nlist.h>
 #include <mach-o/getsect.h>
+
+#ifdef HAVE_MALLOC_MALLOC_H
 #include <malloc/malloc.h>
+#elif HAVE_OBJC_MALLOC_H
+#include <objc/malloc.h>
+#elif
+#error no malloc.h found
+#endif
 
 #include <sys/mman.h>
 
