@@ -22,6 +22,8 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <errno.h>
+#include <time.h>
 
 #define IN_UNIXFSYS
 #include "include.h"
@@ -33,6 +35,10 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef __MINGW32__
 #  include <windows.h>        
+/* Windows has no symlink, therefore no lstat.  Without symlinks lstat
+   is equivalent to stat anyway.  */
+#  define S_ISLNK(a) 0
+#  define lstat stat
 #endif
 
 #ifdef BSD
@@ -233,7 +239,7 @@ truename(object pathname)
 	vs_push(pathname);
 
 	if (wild_pathname_p(pathname,Cnil) == Ct)
-	    return(file_error("File ~S is wild.",pathname));
+	    return(WILD_PATH(pathname));
 
 	coerce_to_local_filename(pathname, filename);
 
@@ -244,7 +250,7 @@ truename(object pathname)
 	    int newlen;
 	    newlen=readlink(filename,newname,MAXPATHLEN-1);
 	    if (newlen < 0)
-		return(file_error("Symlink broken at ~S.",pathname));
+		return(FILE_ERROR(pathname,"Broken symlink"));
 	    for (p = filename, q = 0;  *p != '\0';  p++)
 		    if (*p == '/') q = p;
 	    if (q == 0 || *newname == '/')
@@ -431,7 +437,7 @@ LFD(Ltruename)(void)
 	vs_base[0]=coerce_to_pathname(vs_base[0]);
 
 	if (wild_pathname_p(vs_base[0],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[0]);
+	    WILD_PATH(vs_base[0]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -441,7 +447,7 @@ LFD(Ltruename)(void)
              ((vs_base[0]->pn.pn_type != Cnil) &&
 		(vs_base[0]->pn.pn_type != sKunspecific))) &&
 	    !file_exists(vs_base[0])) {
-	    file_error("File ~S does not exist.",vs_base[0]);
+	    FILE_ERROR(vs_base[0],"File does not exist");
 	    vs_base[0] = Cnil;
 	} else 
 	    vs_base[0] = truename(vs_base[0]);
@@ -457,7 +463,7 @@ LFD(Lrename_file)(void)
 	check_type_or_Pathname_string_symbol(&vs_base[1]);
 
 	if (wild_pathname_p(vs_base[0],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[0]);
+	    WILD_PATH(vs_base[0]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -468,7 +474,7 @@ LFD(Lrename_file)(void)
 	vs_base[1] = merge_pathnames(vs_base[1], vs_base[0], Cnil);
 
 	if (wild_pathname_p(vs_base[1],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[1]);
+	    WILD_PATH(vs_base[1]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -489,6 +495,34 @@ LFD(Lrename_file)(void)
 }
 
 
+DEF_ORDINARY("DIRECTORY",sKdirectory,KEYWORD,"");
+DEF_ORDINARY("LINK",sKlink,KEYWORD,"");
+DEF_ORDINARY("FILE",sKfile,KEYWORD,"");
+
+extern char *ctime_r(const time_t *,char *);
+
+DEFUN_NEW("STAT",object,fSstat,SI,1,1,NONE,OO,OO,OO,OO,(object path),"") {
+
+  char filename[4096];
+  struct stat ss;
+  
+
+  bzero(filename,sizeof(filename));
+  coerce_to_filename(path,filename);
+  if (lstat(filename,&ss))
+    RETURN1(Cnil);
+  else {/* ctime_r insufficiently portable */
+    /* int j;
+       ctime_r(&ss.st_ctime,filename);
+       j=strlen(filename);
+       if (isspace(filename[j-1]))
+       filename[j-1]=0;*/
+    RETURN1(list(3,S_ISDIR(ss.st_mode) ? sKdirectory : 
+		 (S_ISLNK(ss.st_mode) ? sKlink : sKfile),
+		 make_fixnum(ss.st_size),make_fixnum(ss.st_ctime)));
+  }
+}
+
 DEFUN_NEW("SETENV",object,fSsetenv,SI,2,2,NONE,OO,OO,OO,OO,(object variable,object value),"Set environment VARIABLE to VALUE")
 
 {
@@ -521,11 +555,11 @@ DEFUNO_NEW("DELETE-FILE",object,fLdelete_file,LISP
 	check_type_or_pathname_string_symbol_stream(&path);
 
 	if (wild_pathname_p(path,Cnil) == Ct)
-	    RETURN1(file_error("File ~S is wild.",path));
+	    RETURN1(WILD_PATH(path));
 
 	coerce_to_local_filename(path, filename);
-	if (unlink(filename) < 0)
-		FEerror("Cannot delete the file ~S.", 1, path);
+ 	if (unlink(filename) < 0 && rmdir(filename) < 0)
+ 		FEerror("Cannot delete the file ~S: ~s.", 2, path, make_simple_string(strerror(errno)));
 	path = Ct;
 	RETURN1(path);
 }
@@ -543,7 +577,7 @@ LFD(Lprobe_file)(void)
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 
 	if (wild_pathname_p(vs_base[0],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[0]);
+	    WILD_PATH(vs_base[0]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -563,7 +597,7 @@ LFD(Lfile_write_date)(void)
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 
 	if (wild_pathname_p(vs_base[0],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[0]);
+	    WILD_PATH(vs_base[0]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -589,7 +623,7 @@ LFD(Lfile_author)(void)
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 
 	if (wild_pathname_p(vs_base[0],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[0]);
+	    WILD_PATH(vs_base[0]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -836,7 +870,7 @@ FFN(siLchdir)(void)
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 
 	if (wild_pathname_p(vs_base[0],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[0]);
+	    WILD_PATH(vs_base[0]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -856,7 +890,7 @@ FFN(siLmkdir)(void)
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 
 	if (wild_pathname_p(vs_base[0],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[0]);
+	    WILD_PATH(vs_base[0]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -880,7 +914,7 @@ FFN(siLrmdir)(void)
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 
 	if (wild_pathname_p(vs_base[0],Cnil) == Ct) {
-	    file_error("File ~S is wild.",vs_base[0]);
+	    WILD_PATH(vs_base[0]);
 	    vs_base[0] = Cnil;
 	    return;
 	}
@@ -896,7 +930,7 @@ gcl_init_unixfsys(void)
 {
 	make_function("TRUENAME", Ltruename);
 	make_function("RENAME-FILE", Lrename_file);
-	make_function("DELETE-FILE", Ldelete_file);
+/* 	make_function("DELETE-FILE", Ldelete_file); */
 	make_function("PROBE-FILE", Lprobe_file);
 	make_function("FILE-WRITE-DATE", Lfile_write_date);
 	make_function("FILE-AUTHOR", Lfile_author);
