@@ -80,7 +80,7 @@ FFN(siGxdr_write)(object str,object elt) {
       u_int tmp=elt->v.v_fillp;
       if (tmp!=elt->v.v_fillp)
 	goto error;
-      if(!xdr_array(xdrp,(char **)&elt->v.v_self,
+      if(!xdr_array(xdrp,(void *)&elt->v.v_self,
 		    &tmp,
 		    elt->v.v_dim,
 		    aet_types[elt->v.v_elttype].size,
@@ -142,7 +142,7 @@ FFN(siGxdr_read)(object str,object elt) {
       u_int tmp=elt->v.v_fillp;
       if (tmp!=elt->v.v_fillp)
 	goto error;
-      if(!xdr_array(xdrp,(char **)&elt->v.v_self,
+      if(!xdr_array(xdrp,(void *)&elt->v.v_self,
 		    &tmp,
 		    elt->v.v_dim,
 		    aet_types[elt->v.v_elttype].size,
