@@ -73,10 +73,8 @@
 
 ;#+turbo-closure-env-size
 (clines "
-static
-object cclosure_env_nthcdr (n,cc)
-int n; object cc;
-{  object env,*turbo;
+static object cclosure_env_nthcdr (fixnum n,object cc) {
+   object env,*turbo;
    if(n<0)return Cnil;
    if(type_of(cc)!=t_cclosure)return Cnil;
    if((turbo=cc->cc.cc_turbo)==NULL)
@@ -90,9 +88,9 @@ int n; object cc;
       return turbo[n];}
 }")
 
-(defentry cclosure-env-nthcdr (int object) (object cclosure_env_nthcdr))
+(defentry cclosure-env-nthcdr (fixnum object) (static object cclosure_env_nthcdr))
 ;; This is the unsafe but fast version.
-(defentry %cclosure-env-nthcdr (int object) (object cclosure_env_nthcdr))
+(defentry %cclosure-env-nthcdr (fixnum object) (static object cclosure_env_nthcdr))
 
 ;; FIXME The non-inlined versions should really check for uncompiled 
 ;; closeres and set the environment properly in them.  In reality,
@@ -106,8 +104,8 @@ set_cclosure_env(object cc,object val) {
 }
 ")
 
-(defentry set-cclosure-env (object object) (void set_cclosure_env))
-(defentry %set-cclosure-env (object object) (void set_cclosure_env))
+(defentry set-cclosure-env (object object) (static void set_cclosure_env))
+(defentry %set-cclosure-env (object object) (static void set_cclosure_env))
 
 (clines "
 static object
@@ -116,7 +114,7 @@ cclosurep(object o) {
 }
 ")
 
-(defentry cclosurep (object) (object cclosurep))
+(defentry cclosurep (object) (static object cclosurep))
 
 (clines "
 static object
@@ -125,8 +123,8 @@ cclosure_env(object o) {
 }
 ")
 
-(defentry cclosure-env (object) (object cclosure_env))
-(defentry %cclosure-env (object) (object cclosure_env))
+(defentry cclosure-env (object) (static object cclosure_env))
+(defentry %cclosure-env (object) (static object cclosure_env))
 
 (clines "
 static void
@@ -136,8 +134,8 @@ set_compiled_function_name(object o,object n) {
 }
 ")
 
-(defentry si::set-compiled-function-name (object object) (void set_compiled_function_name))
-(defentry si::%set-compiled-function-name (object object) (void set_compiled_function_name))
+(defentry si::set-compiled-function-name (object object) (static void set_compiled_function_name))
+(defentry si::%set-compiled-function-name (object object) (static void set_compiled_function_name))
 
 (clines "
 static object
@@ -147,23 +145,28 @@ return o->s.s_gfdef==OBJNULL ? Cnil : Ct;
 }
 ")
 
-(defentry %fboundp (object) (object __fboundp))
+(defentry %fboundp (object) (static object __fboundp))
+
+(eval-when (compile eval load);FIXME do pushn here from compiler
+(defun do-norm (entry)
+  `(,(car entry) ,(mapcar 'compiler::cmp-norm-tp (cadr entry))
+    ,(compiler::cmp-norm-tp (caddr entry))
+    ,@(cdddr entry)))
 
-(eval-when (compile eval load)
 (defparameter *gcl-function-inlines*
-  '( (%fboundp (t) compiler::boolean nil nil "(#0)->s.s_gfdef!=OBJNULL")
-     (%symbol-function (t) t nil nil "(#0)->s.s_gfdef")
-     (si:%structure-name (t) t nil nil "(#0)->str.str_def->str.str_self[0]")
-    (si:%compiled-function-name (t) t nil nil "(#0)->cf.cf_name")
-    (si:%set-compiled-function-name (t t) t t nil "((#0)->cf.cf_name)=(#1)")
-    (cclosurep (t) compiler::boolean nil nil "type_of(#0)==t_cclosure")
-    (sfun-p (t) compiler::boolean nil nil "type_of(#0)==t_sfun")
-    (%cclosure-env (t) t nil nil "(#0)->cc.cc_env")
-    (%set-cclosure-env (t t) t t nil "((#0)->cc.cc_env)=(#1)")
-    #+turbo-closure
-    (%cclosure-env-nthcdr (fixnum t) t nil nil "(#1)->cc.cc_turbo[#0]")
-    
-    (logxor (fixnum fixnum) fixnum nil nil "((#0) ^ (#1))")))
+  (mapcar 'do-norm
+	  '( (%fboundp (t) compiler::boolean nil nil "(#0)->s.s_gfdef!=OBJNULL")
+	     (%symbol-function (t) t nil nil "(#0)->s.s_gfdef")
+	     (si:%structure-name (t) t nil nil "(#0)->str.str_def->str.str_self[0]")
+	     (si:%compiled-function-name (t) t nil nil "(#0)->cf.cf_name")
+	     (si:%set-compiled-function-name (t t) t t nil "((#0)->cf.cf_name)=(#1)")
+	     (cclosurep (t) compiler::boolean nil nil "type_of(#0)==t_cclosure")
+	     (sfun-p (t) compiler::boolean nil nil "type_of(#0)==t_sfun")
+	     (%cclosure-env (t) t nil nil "(#0)->cc.cc_env")
+	     (%set-cclosure-env (t t) t t nil "((#0)->cc.cc_env)=(#1)")
+	     #+turbo-closure
+	     (%cclosure-env-nthcdr (fixnum t) t nil nil "(#1)->cc.cc_turbo[#0]")
+	     (logxor (fixnum fixnum) fixnum nil nil "((#0) ^ (#1))"))))
 
 (defun make-function-inline (inline)
   (setf (get (car inline) 'compiler::inline-always)
@@ -176,8 +179,7 @@ return o->s.s_gfdef==OBJNULL ? Cnil : Ct;
                                   (if (eq (car inline) 'logxor)
                                       8 0)) ;result type from args
                           (fifth opt)))
-                  (cdr inline)))))
-)
+                  (cdr inline))))))
 
 
 (defmacro define-inlines ()
@@ -190,7 +192,7 @@ return o->s.s_gfdef==OBJNULL ? Cnil : Ct;
                                       (cadr inline))))
                     `((eval-when (compile eval load)
 				 (make-function-inline
-				  ',(cons name (cdr inline))))
+				  `(,',name ,@(cdr (assoc ',(car inline) *gcl-function-inlines*)))))
                       ,@(when (or (every #'(lambda (type) (eq type 't))
                                          (cadr inline))
                                   (char= #\% (aref (symbol-name (car inline)) 0)))
@@ -200,7 +202,7 @@ return o->s.s_gfdef==OBJNULL ? Cnil : Ct;
                                               `((declare (type ,var-type ,var)))))
                                         vars (cadr inline))
                               (the ,(caddr inline) (,name ,@vars)))
-                            (make-function-inline ',inline))))))
+                            (make-function-inline `(,',(car inline) ,@(cdr (assoc ',(car inline) *gcl-function-inlines*)))))))))
               *gcl-function-inlines*)))
 
 (define-inlines)
@@ -225,14 +227,8 @@ return o->s.s_gfdef==OBJNULL ? Cnil : Ct;
 
 
 (clines "
-
-
-
 object fSuse_fast_links_2(object,object);
-static
-object set_cclosure (result_cc,value_cc,available_size)
-  object result_cc,value_cc; int available_size;
-{
+static object set_cclosure (object result_cc,object value_cc,fixnum available_size) {
   object result_env_tail,value_env_tail; int i;
 
   /* If we are currently using fast linking,     */
@@ -251,11 +247,10 @@ object set_cclosure (result_cc,value_cc,available_size)
   result_cc->cc.cc_self=value_cc->cc.cc_self;
   result_cc->cc.cc_data=value_cc->cc.cc_data;
 
-
   return result_cc;
 }")
 
-(defentry %set-cclosure (object object int) (object set_cclosure))
+(defentry %set-cclosure (object object fixnum) (static object set_cclosure))
 
 
 (defun structure-functions-exist-p ()
@@ -296,7 +291,7 @@ object set_cclosure (result_cc,value_cc,available_size)
   (or (cdr (gethash type *structure-table*))
       (mapcan #'(lambda (slotd)
                   (when (and slotd (car slotd))
-                    (let ((read-only-p (fourth slotd))
+                    (let (;(read-only-p (fourth slotd))
 			  (offset (fifth slotd)))
                       (let ((reader (lambda (x) (si:structure-ref1 x offset)))
                             (writer ;(if read-only-p
