@@ -62,6 +62,7 @@ gcl_init_init()
 
   lsp_init("../lsp/gcl_export.lsp");
 
+  ar_init(gcl_callhash);
   ar_init(gcl_defmacro);
   ar_init(gcl_evalmacros);
   ar_init(gcl_top);
@@ -104,13 +105,14 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_ansi_io,no_init); 
 
 	
+  ar_check_init(gcl_cmptype,no_init);
   ar_check_init(gcl_cmpinline,no_init);
   ar_check_init(gcl_cmputil,no_init);
 
   ar_check_init(gcl_debug,no_init);
   ar_check_init(gcl_info,no_init);
 
-  ar_check_init(gcl_cmptype,no_init);
+/*   ar_check_init(gcl_cmptype,no_init); */
   ar_check_init(gcl_cmpbind,no_init);
   ar_check_init(gcl_cmpblock,no_init);
   ar_check_init(gcl_cmpcall,no_init);
@@ -134,8 +136,27 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_cmpwt,no_init);
   ar_check_init(gcl_cmpmain,no_init);
 
+  lsp_init("../clcs/package.lisp");
   lsp_init("../clcs/myload1.lisp");
 
+#ifdef HAVE_XGCL
+  lsp_init("../xgcl-2/sysdef.lisp");
+  ar_check_init(gcl_Xlib,no_init);
+  ar_check_init(gcl_Xutil,no_init);
+  ar_check_init(gcl_X,no_init);
+  ar_check_init(gcl_XAtom,no_init);
+  ar_check_init(gcl_defentry_events,no_init);
+  ar_check_init(gcl_Xstruct,no_init);
+  ar_check_init(gcl_XStruct_l_3,no_init);
+  ar_check_init(gcl_general,no_init);
+  ar_check_init(gcl_keysymdef,no_init);
+  ar_check_init(gcl_X10,no_init);
+  ar_check_init(gcl_Xinit,no_init);
+  ar_check_init(gcl_dwtrans,no_init);
+  ar_check_init(gcl_tohtml,no_init);
+  ar_check_init(gcl_index,no_init);
+#endif
+  
   ar_check_init(gcl_pcl_pkg,no_init);
   ar_check_init(gcl_pcl_walk,no_init);
   ar_check_init(gcl_pcl_iterate,no_init);
@@ -174,14 +195,17 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_clcs_precom,no_init);
   ar_check_init(gcl_clcs_macros,no_init);
   ar_check_init(gcl_clcs_restart,no_init);
-  ar_check_init(gcl_clcs_handler,no_init);
   ar_check_init(gcl_clcs_debugger,no_init);
+  ar_check_init(gcl_clcs_handler,no_init);
   ar_check_init(gcl_clcs_conditions,no_init);
   ar_check_init(gcl_clcs_condition_definitions,no_init);
   ar_check_init(gcl_clcs_kcl_cond,no_init);
   ar_check_init(gcl_clcs_top_patches,no_init);
   ar_check_init(gcl_clcs_install,no_init);
-  
+#ifdef _WIN32  
+  ar_check_init(gcl_win32,no_init);
+#endif  
+#include "recompile.h"
 }
 
 static int ngazonk;
