@@ -61,7 +61,7 @@ gcl_init_init()
   build_symbol_table();
 
   lsp_init("../lsp/gcl_export.lsp");
-
+  ar_init(gcl_callhash);
   ar_init(gcl_defmacro);
   ar_init(gcl_evalmacros);
   ar_init(gcl_top);
@@ -85,8 +85,16 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_defstruct,no_init);
   ar_check_init(gcl_describe,no_init);
 #ifdef HAVE_JAPI_H
-  lsp_init("../mod/gcl_japi.lsp"); /* Needed for package declaration when compiling later. */
+  lsp_init("../mod/gcl_japi.lsp");  /* Needed for package declaration when compiling later. */
 #endif
+#ifdef HAVE_TK
+  lsp_init("../mod/gcl_tk.lsp");    /* Needed for package declaration when compiling later. */
+#endif
+#if 0
+#ifdef _WIN32  
+  lsp_init("../mod/gcl_win32.lsp"); /* Needed for package declaration when compiling later. */
+#endif
+#endif  
   ar_check_init(gcl_iolib,no_init);
   ar_check_init(gcl_listlib,no_init);
   ar_check_init(gcl_mislib,no_init);
@@ -98,13 +106,14 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_sloop,no_init);
   ar_check_init(gcl_serror,no_init);
 	
+  ar_check_init(gcl_cmptype,no_init);
   ar_check_init(gcl_cmpinline,no_init);
   ar_check_init(gcl_cmputil,no_init);
 
   ar_check_init(gcl_debug,no_init);
   ar_check_init(gcl_info,no_init);
 
-  ar_check_init(gcl_cmptype,no_init);
+/*   ar_check_init(gcl_cmptype,no_init); */
   ar_check_init(gcl_cmpbind,no_init);
   ar_check_init(gcl_cmpblock,no_init);
   ar_check_init(gcl_cmpcall,no_init);
@@ -128,6 +137,25 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_cmpwt,no_init);
   ar_check_init(gcl_cmpmain,no_init);
 
+#ifdef HAVE_XGCL
+  lsp_init("../xgcl-2/sysdef.lisp");
+  ar_check_init(gcl_Xlib,no_init);
+  ar_check_init(gcl_Xutil,no_init);
+  ar_check_init(gcl_X,no_init);
+  ar_check_init(gcl_XAtom,no_init);
+  ar_check_init(gcl_defentry_events,no_init);
+  ar_check_init(gcl_Xstruct,no_init);
+  ar_check_init(gcl_XStruct_l_3,no_init);
+  ar_check_init(gcl_general,no_init);
+  ar_check_init(gcl_keysymdef,no_init);
+  ar_check_init(gcl_X10,no_init);
+  ar_check_init(gcl_Xinit,no_init);
+  ar_check_init(gcl_dwtrans,no_init);
+  ar_check_init(gcl_tohtml,no_init);
+  ar_check_init(gcl_index,no_init);
+#endif
+    
+#include "recompile.h"
   
 }
 
