@@ -62,6 +62,7 @@ gcl_init_init()
 
   lsp_init("../lsp/gcl_export.lsp");
 
+  ar_init(gcl_callhash);
   ar_init(gcl_defmacro);
   ar_init(gcl_evalmacros);
   ar_init(gcl_top);
@@ -86,6 +87,9 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_describe,no_init);
 #ifdef HAVE_JAPI_H
   ar_check_init(gcl_japi,no_init);
+#endif
+#ifdef HAVE_TK
+  ar_check_init(gcl_tk,no_init);
 #endif
   ar_check_init(gcl_iolib,no_init);
   ar_check_init(gcl_listlib,no_init);
@@ -104,13 +108,14 @@ gcl_init_system(object no_init)
   /* ar_check_init(gcl_ansi_io,no_init); deleted by kraehe */
 
 	
+  ar_check_init(gcl_cmptype,no_init);
   ar_check_init(gcl_cmpinline,no_init);
   ar_check_init(gcl_cmputil,no_init);
 
   ar_check_init(gcl_debug,no_init);
   ar_check_init(gcl_info,no_init);
 
-  ar_check_init(gcl_cmptype,no_init);
+/*   ar_check_init(gcl_cmptype,no_init); */
   ar_check_init(gcl_cmpbind,no_init);
   ar_check_init(gcl_cmpblock,no_init);
   ar_check_init(gcl_cmpcall,no_init);
@@ -137,6 +142,24 @@ gcl_init_system(object no_init)
   lsp_init("../clcs/package.lisp");
   lsp_init("../clcs/myload1.lisp");
 
+#ifdef HAVE_XGCL
+  lsp_init("../xgcl-2/sysdef.lisp");
+  ar_check_init(gcl_Xlib,no_init);
+  ar_check_init(gcl_Xutil,no_init);
+  ar_check_init(gcl_X,no_init);
+  ar_check_init(gcl_XAtom,no_init);
+  ar_check_init(gcl_defentry_events,no_init);
+  ar_check_init(gcl_Xstruct,no_init);
+  ar_check_init(gcl_XStruct_l_3,no_init);
+  ar_check_init(gcl_general,no_init);
+  ar_check_init(gcl_keysymdef,no_init);
+  ar_check_init(gcl_X10,no_init);
+  ar_check_init(gcl_Xinit,no_init);
+  ar_check_init(gcl_dwtrans,no_init);
+  ar_check_init(gcl_tohtml,no_init);
+  ar_check_init(gcl_index,no_init);
+#endif
+  
   ar_check_init(gcl_pcl_pkg,no_init);
   ar_check_init(gcl_pcl_walk,no_init);
   ar_check_init(gcl_pcl_iterate,no_init);
@@ -171,7 +194,10 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_pcl_compat,no_init);
   ar_check_init(gcl_pcl_precom1,no_init);
   ar_check_init(gcl_pcl_precom2,no_init);
-
+#ifdef _WIN32  
+  ar_check_init(gcl_win32,no_init);
+#endif
+  
 }
 
 static int ngazonk;
